"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QToolBar(QWidget):
    """
    https://doc.qt.io/qt-6/qtoolbar.html

    **Detailed Description**

    Toolbar buttons are added by adding **actions** , using **addAction** () or
    **insertAction** (). Groups of buttons can be separated using
    **addSeparator** () or **insertSeparator** (). If a toolbar button is not
    appropriate, a widget can be inserted instead using **addWidget** () or
    **insertWidget** (). Examples of suitable widgets are **QSpinBox** ,
    **QDoubleSpinBox** , and **QComboBox** . When a toolbar button is pressed,
    it emits the **actionTriggered** () signal.

    A toolbar can be fixed in place in a particular area (e.g., at the top of
    the window), or it can be movable between toolbar areas; see **setMovable**
    (), **isMovable** (), **allowedAreas** () and **isAreaAllowed** ().

    When a toolbar is resized in such a way that it is too small to show all the
    items it contains, an extension button will appear as the last item in the
    toolbar. Pressing the extension button will pop up a menu containing the
    items that do not currently fit in the toolbar.

    When a QToolBar is not a child of a **QMainWindow** , it loses the ability
    to populate the extension pop up with widgets added to the toolbar using
    **addWidget** (). Please use widget actions created by inheriting
    **QWidgetAction**  and implementing **QWidgetAction::createWidget** ()
    instead.

    **See also** **QToolButton** , **QMenu** , **QAction** , and **Qt Widgets -
    Application Example** .
    """

    @typing.overload
    def __init__(self, title: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#QToolBar

        **QToolBar::QToolBar(const QString & title , QWidget * parent =
        nullptr)**

        Constructs a QToolBar with the given **parent**.

        The given window **title** identifies the toolbar and is shown in the
        context menu provided by **QMainWindow** .

        **See also** **setWindowTitle** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#QToolBar-1

        **QToolBar::QToolBar(QWidget * parent = nullptr)**

        Constructs a QToolBar with the given **parent**.
        """
        ...

    def isFloating(self) -> bool:
        ...

    def setFloatable(self, floatable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#floatable-prop

        **floatable : bool**

        This property holds whether the toolbar can be dragged and dropped as an
        independent window.

        The default is true.

        **Access functions:**

        bool **isFloatable** () const
        void **setFloatable** (bool
        **floatable** )
        """
        ...

    def isFloatable(self) -> bool:
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#event

        **[override virtual protected] bool QToolBar::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#paintEvent

        **[override virtual protected] void QToolBar::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def changeEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#changeEvent

        **[override virtual protected] void QToolBar::changeEvent(QEvent * event
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def actionEvent(self, event: QtGui.QActionEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#actionEvent

        **[override virtual protected] void QToolBar::actionEvent(QActionEvent *
        event )**

        Reimplements: **QWidget::actionEvent** (QActionEvent *event).
        """
        ...

    def initStyleOption(self, option: QStyleOptionToolBar) -> None:
        ...

    def setToolButtonStyle(self, toolButtonStyle: QtCore.Qt.ToolButtonStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#toolButtonStyle-prop

        **toolButtonStyle : Qt::ToolButtonStyle**

        This property holds the style of toolbar buttons

        This property defines the style of all tool buttons that are added as
        **QAction** s. Note that if you add a **QToolButton**  with the
        **addWidget** () method, it will not get this button style.

        To have the style of toolbuttons follow the system settings, set this
        property to **Qt::ToolButtonFollowStyle** . On Unix, the user settings
        from the desktop environment will be used. On other platforms,
        **Qt::ToolButtonFollowStyle**  means icon only.

        The default is **Qt::ToolButtonIconOnly** .

        **Access functions:**

        Qt::ToolButtonStyle **toolButtonStyle** () const
        void
        **setToolButtonStyle** (Qt::ToolButtonStyle **toolButtonStyle** )

        **Notifier signal:**

        void ****toolButtonStyleChanged** ** (Qt::ToolButtonStyle
        **toolButtonStyle** )

        **Member Function Documentation**
        """
        ...

    def setIconSize(self, iconSize: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#iconSize-prop

        **iconSize : QSize**

        size of icons in the toolbar.

        The default size is determined by the application's style and is derived
        from the **QStyle::PM_ToolBarIconSize**  pixel metric. It is the maximum
        size an icon can have. Icons of smaller size will not be scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **iconSize** )

        **Notifier signal:**

        void ****iconSizeChanged** ** (const QSize & **iconSize** )
        """
        ...

    def widgetForAction(self, action: QtGui.QAction) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#widgetForAction

        **QWidget *QToolBar::widgetForAction(QAction * action ) const**

        Returns the widget associated with the specified **action**.

        **See also** **addWidget** ().
        """
        ...

    def toolButtonStyle(self) -> QtCore.Qt.ToolButtonStyle:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#toolButtonStyle-prop

        **toolButtonStyle : Qt::ToolButtonStyle**

        This property holds the style of toolbar buttons

        This property defines the style of all tool buttons that are added as
        **QAction** s. Note that if you add a **QToolButton**  with the
        **addWidget** () method, it will not get this button style.

        To have the style of toolbuttons follow the system settings, set this
        property to **Qt::ToolButtonFollowStyle** . On Unix, the user settings
        from the desktop environment will be used. On other platforms,
        **Qt::ToolButtonFollowStyle**  means icon only.

        The default is **Qt::ToolButtonIconOnly** .

        **Access functions:**

        Qt::ToolButtonStyle **toolButtonStyle** () const
        void
        **setToolButtonStyle** (Qt::ToolButtonStyle **toolButtonStyle** )

        **Notifier signal:**

        void ****toolButtonStyleChanged** ** (Qt::ToolButtonStyle
        **toolButtonStyle** )

        **Member Function Documentation**
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#iconSize-prop

        **iconSize : QSize**

        size of icons in the toolbar.

        The default size is determined by the application's style and is derived
        from the **QStyle::PM_ToolBarIconSize**  pixel metric. It is the maximum
        size an icon can have. Icons of smaller size will not be scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **iconSize** )

        **Notifier signal:**

        void ****iconSizeChanged** ** (const QSize & **iconSize** )
        """
        ...

    def toggleViewAction(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#toggleViewAction

        **QAction *QToolBar::toggleViewAction() const**

        Returns a checkable action that can be used to show or hide this
        toolbar.

        The action's text is set to the toolbar's window title.

        **See also** **QAction::text**  and **QWidget::windowTitle** .
        """
        ...

    @typing.overload
    def actionAt(self, p: QtCore.QPoint) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#actionAt

        **QAction *QToolBar::actionAt(const QPoint & p ) const**

        Returns the action at point **p**. This function returns zero if no
        action was found.

        **See also** **QWidget::childAt** ().
        """
        ...

    @typing.overload
    def actionAt(self, ax: int, ay: int) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#actionAt-1

        **QAction *QToolBar::actionAt(int x , int y ) const**

        This is an overloaded function.

        Returns the action at the point **x** , **y**. This function returns
        zero if no action was found.
        """
        ...

    def actionGeometry(self, action: QtGui.QAction) -> QtCore.QRect:
        ...

    def insertWidget(self, before: QtGui.QAction, widget: QWidget) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#insertWidget

        **QAction *QToolBar::insertWidget(QAction * before , QWidget * widget
        )**

        Inserts the given **widget** in front of the toolbar item associated
        with the **before** action.

        Note: You should use **QAction::setVisible** () to change the visibility
        of the widget. Using **QWidget::setVisible** (), **QWidget::show** ()
        and **QWidget::hide** () does not work.

        **See also** **addWidget** ().
        """
        ...

    def addWidget(self, widget: QWidget) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addWidget

        **QAction *QToolBar::addWidget(QWidget * widget )**

        Adds the given **widget** to the toolbar as the toolbar's last item.

        The toolbar takes ownership of **widget**.

        If you add a **QToolButton**  with this method, the toolbar's
        **Qt::ToolButtonStyle**  will not be respected.

        **Note:** You should use **QAction::setVisible** () to change the
        visibility of the widget. Using **QWidget::setVisible** (),
        **QWidget::show** () and **QWidget::hide** () does not work.

        **See also** **insertWidget** ().
        """
        ...

    def insertSeparator(self, before: QtGui.QAction) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#insertSeparator

        **QAction *QToolBar::insertSeparator(QAction * before )**

        Inserts a separator into the toolbar in front of the toolbar item
        associated with the **before** action.

        **See also** **addSeparator** ().
        """
        ...

    def addSeparator(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addSeparator

        **QAction *QToolBar::addSeparator()**

        Adds a separator to the end of the toolbar.

        **See also** **insertSeparator** ().
        """
        ...

    @typing.overload
    def addAction(self, a0: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addAction

        **QAction *QToolBar::addAction(const QString & text )**

        Creates a new action with the given **text**. This action is added to
        the end of the toolbar.
        """
        ...

    @typing.overload
    def addAction(self, text: str) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addAction-1

        **QAction *QToolBar::addAction(const QIcon & icon , const QString & text
        )**

        This is an overloaded function.

        Creates a new action with the given **icon** and **text**. This action
        is added to the end of the toolbar.
        """
        ...

    @typing.overload
    def addAction(self, icon: QtGui.QIcon, text: str) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addAction-2

        **QAction *QToolBar::addAction(const QString & text , const QObject *
        receiver , const char * member )**

        This is an overloaded function.

        Creates a new action with the given **text**. This action is added to
        the end of the toolbar. The action's **triggered** () signal is
        connected to **member** in **receiver**.
        """
        ...

    @typing.overload
    def addAction(self, text: str, slot: PYQT_SLOT) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addAction-3

        **QAction *QToolBar::addAction(const QIcon & icon , const QString & text
        , const QObject * receiver , const char * member )**

        This is an overloaded function.

        Creates a new action with the given **icon** and **text**. This action
        is added to the end of the toolbar. The action's **triggered** () signal
        is connected to **member** in **receiver**.
        """
        ...

    @typing.overload
    def addAction(self, icon: QtGui.QIcon, text: str, slot: PYQT_SLOT) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#addAction-4

        **[since 5.6] template <typename Functor> QAction
        *QToolBar::addAction(const QString & text , Functor functor )**

        This is an overloaded function.

        Creates a new action with the given **text**. This action is added to
        the end of the toolbar. The action's **triggered** () signal is
        connected to the **functor**.

        This function was introduced in Qt 5.6.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#clear

        **void QToolBar::clear()**

        Removes all actions from the toolbar.

        **See also** **removeAction** ().
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#orientation-prop

        **orientation : Qt::Orientation**

        orientation of the toolbar

        The default is **Qt::Horizontal** .

        This function should not be used when the toolbar is managed by
        **QMainWindow** . You can use **QMainWindow::addToolBar** () or
        **QMainWindow::insertToolBar** () if you wish to move a toolbar that is
        already added to a main window to another **Qt::ToolBarArea** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation **orientation** )

        **Notifier signal:**

        void ****orientationChanged** ** (Qt::Orientation **orientation** )
        """
        ...

    def setOrientation(self, orientation: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#orientation-prop

        **orientation : Qt::Orientation**

        orientation of the toolbar

        The default is **Qt::Horizontal** .

        This function should not be used when the toolbar is managed by
        **QMainWindow** . You can use **QMainWindow::addToolBar** () or
        **QMainWindow::insertToolBar** () if you wish to move a toolbar that is
        already added to a main window to another **Qt::ToolBarArea** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation **orientation** )

        **Notifier signal:**

        void ****orientationChanged** ** (Qt::Orientation **orientation** )
        """
        ...

    def isAreaAllowed(self, area: QtCore.Qt.ToolBarArea) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#isAreaAllowed

        **bool QToolBar::isAreaAllowed(Qt::ToolBarArea area ) const**

        Returns `true` if this toolbar is dockable in the given **area** ;
        otherwise returns `false`.
        """
        ...

    def allowedAreas(self) -> QtCore.Qt.ToolBarArea:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#allowedAreas-prop

        **allowedAreas : Qt::ToolBarAreas**

        areas where the toolbar may be placed

        The default is **Qt::AllToolBarAreas** .

        This property only makes sense if the toolbar is in a **QMainWindow** .

        **Access functions:**

        Qt::ToolBarAreas **allowedAreas** () const
        void **setAllowedAreas**
        (Qt::ToolBarAreas **areas** )

        **Notifier signal:**

        void ****allowedAreasChanged** ** (Qt::ToolBarAreas **allowedAreas** )

        **See also** **movable** .
        """
        ...

    def setAllowedAreas(self, areas: QtCore.Qt.ToolBarArea) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#allowedAreas-prop

        **allowedAreas : Qt::ToolBarAreas**

        areas where the toolbar may be placed

        The default is **Qt::AllToolBarAreas** .

        This property only makes sense if the toolbar is in a **QMainWindow** .

        **Access functions:**

        Qt::ToolBarAreas **allowedAreas** () const
        void **setAllowedAreas**
        (Qt::ToolBarAreas **areas** )

        **Notifier signal:**

        void ****allowedAreasChanged** ** (Qt::ToolBarAreas **allowedAreas** )

        **See also** **movable** .
        """
        ...

    def isMovable(self) -> bool:
        ...

    def setMovable(self, movable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#movable-prop

        **movable : bool**

        This property holds whether the user can move the toolbar within the
        toolbar area, or between toolbar areas.

        By default, this property is `true`.

        This property only makes sense if the toolbar is in a **QMainWindow** .

        **Access functions:**

        bool **isMovable** () const
        void **setMovable** (bool **movable** )

        **Notifier signal:**

        void ****movableChanged** ** (bool **movable** )

        **See also** **allowedAreas** .
        """
        ...

    @property
    def actionTriggered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#actionTriggered

        **[signal] void QToolBar::actionTriggered(QAction * action )**

        This signal is emitted when an action in this toolbar is triggered. This
        happens when the action's tool button is pressed, or when the action is
        triggered in some other way outside the toolbar. The parameter holds the
        triggered **action**.
        """
        ...

    @property
    def allowedAreasChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#allowedAreasChanged

        **[signal] void QToolBar::allowedAreasChanged(Qt::ToolBarAreas
        allowedAreas )**

        This signal is emitted when the collection of allowed areas for the
        toolbar is changed. The new areas in which the toolbar can be positioned
        are specified by **allowedAreas**.

        **Note:** Notifier signal for property **allowedAreas** .

        **See also** **allowedAreas** .
        """
        ...

    @property
    def iconSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#iconSizeChanged

        **[signal] void QToolBar::iconSizeChanged(const QSize & iconSize )**

        This signal is emitted when the icon size is changed. The **iconSize**
        parameter holds the toolbar's new icon size.

        **Note:** Notifier signal for property **iconSize** .

        **See also** **iconSize**  and **QMainWindow::iconSize** .
        """
        ...

    @property
    def movableChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#movableChanged

        **[signal] void QToolBar::movableChanged(bool movable )**

        This signal is emitted when the toolbar becomes movable or fixed. If the
        toolbar can be moved, **movable** is true; otherwise it is false.

        **Note:** Notifier signal for property **movable** .

        **See also** **movable** .
        """
        ...

    @property
    def orientationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#orientationChanged

        **[signal] void QToolBar::orientationChanged(Qt::Orientation orientation
        )**

        This signal is emitted when the orientation of the toolbar changes. The
        **orientation** parameter holds the toolbar's new orientation.

        **Note:** Notifier signal for property **orientation** .

        **See also** **orientation** .
        """
        ...

    @property
    def toolButtonStyleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#toolButtonStyleChanged

        **[signal] void QToolBar::toolButtonStyleChanged(Qt::ToolButtonStyle
        toolButtonStyle )**

        This signal is emitted when the tool button style is changed. The
        **toolButtonStyle** parameter holds the toolbar's new tool button style.

        **Note:** Notifier signal for property **toolButtonStyle** .

        **See also** **toolButtonStyle**  and **QMainWindow::toolButtonStyle** .
        """
        ...

    @property
    def topLevelChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#topLevelChanged

        **[signal] void QToolBar::topLevelChanged(bool topLevel )**

        This signal is emitted when the **floating**  property changes. The
        **topLevel** parameter is true if the toolbar is now floating; otherwise
        it is false.

        **See also** **isWindow** ().
        """
        ...

    @property
    def visibilityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbar.html#visibilityChanged

        **[signal] void QToolBar::visibilityChanged(bool visible )**

        This signal is emitted when the toolbar becomes **visible** (or
        invisible). This happens when the widget is hidden or shown.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QAbstractSocket(QtCore.QIODevice):
    """
    https://doc.qt.io/qt-6/qabstractsocket.html

    **Detailed Description**

    QAbstractSocket is the base class for **QTcpSocket**  and **QUdpSocket**
    and contains all common functionality of these two classes. If you need a
    socket, you have two options:

    * Instantiate **QTcpSocket**  or **QUdpSocket** .
      * Create a native socket
    descriptor, instantiate QAbstractSocket, and call **setSocketDescriptor** ()
    to wrap the native socket.

    TCP (Transmission Control Protocol) is a reliable, stream-oriented,
    connection-oriented transport protocol. UDP (User Datagram Protocol) is an
    unreliable, datagram-oriented, connectionless protocol. In practice, this
    means that TCP is better suited for continuous transmission of data, whereas
    the more lightweight UDP can be used when reliability isn't important.

    QAbstractSocket's API unifies most of the differences between the two
    protocols. For example, although UDP is connectionless, **connectToHost** ()
    establishes a virtual connection for UDP sockets, enabling you to use
    QAbstractSocket in more or less the same way regardless of the underlying
    protocol. Internally, QAbstractSocket remembers the address and port passed
    to **connectToHost** (), and functions like **read** () and **write** () use
    these values.

    At any time, QAbstractSocket has a state (returned by **state** ()). The
    initial state is **UnconnectedState** . After calling **connectToHost** (),
    the socket first enters **HostLookupState** . If the host is found,
    QAbstractSocket enters **ConnectingState**  and emits the **hostFound** ()
    signal. When the connection has been established, it enters
    **ConnectedState**  and emits **connected** (). If an error occurs at any
    stage, **errorOccurred** () is emitted. Whenever the state changes,
    **stateChanged** () is emitted. For convenience, **isValid** () returns
    `true` if the socket is ready for reading and writing, but note that the
    socket's state must be **ConnectedState**  before reading and writing can
    occur.

    Read or write data by calling **read** () or **write** (), or use the
    convenience functions **readLine** () and **readAll** (). QAbstractSocket
    also inherits **getChar** (), **putChar** (), and **ungetChar** () from
    **QIODevice** , which work on single bytes. The **bytesWritten** () signal
    is emitted when data has been written to the socket. Note that Qt does not
    limit the write buffer size. You can monitor its size by listening to this
    signal.

    The **readyRead** () signal is emitted every time a new chunk of data has
    arrived. **bytesAvailable** () then returns the number of bytes that are
    available for reading. Typically, you would connect the **readyRead** ()
    signal to a slot and read all available data there. If you don't read all
    the data at once, the remaining data will still be available later, and any
    new incoming data will be appended to QAbstractSocket's internal read
    buffer. To limit the size of the read buffer, call **setReadBufferSize** ().

    To close the socket, call **disconnectFromHost** (). QAbstractSocket enters
    **QAbstractSocket::ClosingState** . After all pending data has been written
    to the socket, QAbstractSocket actually closes the socket, enters
    **QAbstractSocket::UnconnectedState** , and emits **disconnected** (). If
    you want to abort a connection immediately, discarding all pending data,
    call **abort** () instead. If the remote host closes the connection,
    QAbstractSocket will emit **errorOccurred**
    (**QAbstractSocket::RemoteHostClosedError** ), during which the socket state
    will still be **ConnectedState** , and then the **disconnected** () signal
    will be emitted.

    The port and address of the connected peer is fetched by calling
    **peerPort** () and **peerAddress** (). **peerName** () returns the host
    name of the peer, as passed to **connectToHost** (). **localPort** () and
    **localAddress** () return the port and address of the local socket.

    QAbstractSocket provides a set of functions that suspend the calling thread
    until certain signals are emitted. These functions can be used to implement
    blocking sockets:

    * **waitForConnected** () blocks until a connection has been established.
    * **waitForReadyRead** () blocks until new data is available for reading.
    * **waitForBytesWritten** () blocks until one payload of data has been
    written to the socket.
      * **waitForDisconnected** () blocks until the
    connection has closed.

    We show an example:

    int numRead = 0, numReadTotal = 0;
            char buffer[50];
    forever {
                numRead  = socket.read(buffer, 50);
    // do whatever with array

                numReadTotal += numRead;
    if (numRead == 0 && !socket.waitForReadyRead())
                    break;
    }

    If **waitForReadyRead** () returns `false`, the connection has been closed
    or an error has occurred.

    Programming with a blocking socket is radically different from programming
    with a non-blocking socket. A blocking socket doesn't require an event loop
    and typically leads to simpler code. However, in a GUI application, blocking
    sockets should only be used in non-GUI threads, to avoid freezing the user
    interface. See the **fortuneclient**  and **blockingfortuneclient**
    examples for an overview of both approaches.

    **Note:** We discourage the use of the blocking functions together with
    signals. One of the two possibilities should be used.

    QAbstractSocket can be used with **QTextStream**  and **QDataStream** 's
    stream operators (operator<<() and operator>>()). There is one issue to be
    aware of, though: You must make sure that enough data is available before
    attempting to read it using operator>>().

    **See also** **QNetworkAccessManager**  and **QTcpServer** .
    """

    class PauseMode(enum.Flag):
        PauseNever: QAbstractSocket = ...
        PauseOnSslErrors: QAbstractSocket = ...

    class BindFlag(enum.Flag):
        DefaultForPlatform: QAbstractSocket = ...
        ShareAddress: QAbstractSocket = ...
        DontShareAddress: QAbstractSocket = ...
        ReuseAddressHint: QAbstractSocket = ...

    class SocketOption(enum.Enum):
        LowDelayOption: QAbstractSocket = ...
        KeepAliveOption: QAbstractSocket = ...
        MulticastTtlOption: QAbstractSocket = ...
        MulticastLoopbackOption: QAbstractSocket = ...
        TypeOfServiceOption: QAbstractSocket = ...
        SendBufferSizeSocketOption: QAbstractSocket = ...
        ReceiveBufferSizeSocketOption: QAbstractSocket = ...
        PathMtuSocketOption: QAbstractSocket = ...

    class SocketState(enum.Enum):
        UnconnectedState: QAbstractSocket = ...
        HostLookupState: QAbstractSocket = ...
        ConnectingState: QAbstractSocket = ...
        ConnectedState: QAbstractSocket = ...
        BoundState: QAbstractSocket = ...
        ListeningState: QAbstractSocket = ...
        ClosingState: QAbstractSocket = ...

    class SocketError(enum.Enum):
        ConnectionRefusedError: QAbstractSocket = ...
        RemoteHostClosedError: QAbstractSocket = ...
        HostNotFoundError: QAbstractSocket = ...
        SocketAccessError: QAbstractSocket = ...
        SocketResourceError: QAbstractSocket = ...
        SocketTimeoutError: QAbstractSocket = ...
        DatagramTooLargeError: QAbstractSocket = ...
        NetworkError: QAbstractSocket = ...
        AddressInUseError: QAbstractSocket = ...
        SocketAddressNotAvailableError: QAbstractSocket = ...
        UnsupportedSocketOperationError: QAbstractSocket = ...
        UnfinishedSocketOperationError: QAbstractSocket = ...
        ProxyAuthenticationRequiredError: QAbstractSocket = ...
        SslHandshakeFailedError: QAbstractSocket = ...
        ProxyConnectionRefusedError: QAbstractSocket = ...
        ProxyConnectionClosedError: QAbstractSocket = ...
        ProxyConnectionTimeoutError: QAbstractSocket = ...
        ProxyNotFoundError: QAbstractSocket = ...
        ProxyProtocolError: QAbstractSocket = ...
        OperationError: QAbstractSocket = ...
        SslInternalError: QAbstractSocket = ...
        SslInvalidUserDataError: QAbstractSocket = ...
        TemporaryError: QAbstractSocket = ...
        UnknownSocketError: QAbstractSocket = ...

    class NetworkLayerProtocol(enum.Enum):
        IPv4Protocol: QAbstractSocket = ...
        IPv6Protocol: QAbstractSocket = ...
        AnyIPProtocol: QAbstractSocket = ...
        UnknownNetworkLayerProtocol: QAbstractSocket = ...

    class SocketType(enum.Enum):
        TcpSocket: QAbstractSocket = ...
        UdpSocket: QAbstractSocket = ...
        SctpSocket: QAbstractSocket = ...
        UnknownSocketType: QAbstractSocket = ...

    def __init__(
        self, socketType: "QAbstractSocket.SocketType", parent: QtCore.QObject
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#QAbstractSocket

        **QAbstractSocket::QAbstractSocket(QAbstractSocket::SocketType
        socketType , QObject * parent )**

        Creates a new abstract socket of type **socketType**. The **parent**
        argument is passed to **QObject** 's constructor.

        **See also** **socketType** (), **QTcpSocket** , and **QUdpSocket** .
        """
        ...

    def setProtocolTag(self, tag: str) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setProtocolTag

        **[since 5.13] void QAbstractSocket::setProtocolTag(const QString & tag
        )**

        Sets the protocol tag for this socket to **tag**.

        This function was introduced in Qt 5.13.

        **See also** **protocolTag** ().
        """
        ...

    def protocolTag(self) -> str:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#protocolTag

        **[since 5.13] QString QAbstractSocket::protocolTag() const**

        Returns the protocol tag for this socket. If the protocol tag is set
        then this is passed to **QNetworkProxyQuery**  when this is created
        internally to indicate the protocol tag to be used.

        This function was introduced in Qt 5.13.

        **See also** **setProtocolTag** () and **QNetworkProxyQuery** .
        """
        ...

    @typing.overload
    def bind(
        self,
        address: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"],
        port: int = ...,
        mode: "QAbstractSocket.BindFlag" = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#bind

        **[virtual, since 5.0] bool QAbstractSocket::bind(const QHostAddress &
        address , quint16 port = 0, QAbstractSocket::BindMode mode =
        DefaultForPlatform)**

        Binds to **address** on port **port** , using the **BindMode**
        **mode**.

        For UDP sockets, after binding, the signal **QUdpSocket::readyRead** ()
        is emitted whenever a UDP datagram arrives on the specified address and
        port. Thus, this function is useful to write UDP servers.

        For TCP sockets, this function may be used to specify which interface to
        use for an outgoing connection, which is useful in case of multiple
        network interfaces.

        By default, the socket is bound using the **DefaultForPlatform**
        **BindMode** . If a port is not specified, a random port is chosen.

        On success, the function returns `true` and the socket enters
        **BoundState** ; otherwise it returns `false`.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def bind(self, port: int = ..., mode: "QAbstractSocket.BindFlag" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#bind-1

        **[since 6.2] bool QAbstractSocket::bind(QHostAddress::SpecialAddress
        addr , quint16 port = 0, QAbstractSocket::BindMode mode =
        DefaultForPlatform)**

        This is an overloaded function.

        Binds to the special address **addr** on port **port** , using the
        **BindMode**  **mode**.

        By default, the socket is bound using the **DefaultForPlatform**
        **BindMode** . If a port is not specified, a random port is chosen.

        This function was introduced in Qt 6.2.
        """
        ...

    def setPauseMode(self, pauseMode: "QAbstractSocket.PauseMode") -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setPauseMode

        **[since 5.0] void
        QAbstractSocket::setPauseMode(QAbstractSocket::PauseModes pauseMode )**

        Controls whether to pause upon receiving a notification. The
        **pauseMode** parameter specifies the conditions in which the socket
        should be paused. The only notification currently supported is
        **QSslSocket::sslErrors** (). If set to **PauseOnSslErrors** , data
        transfer on the socket will be paused and needs to be enabled explicitly
        again by calling **resume** (). By default this option is set to
        **PauseNever** . This option must be called before connecting to the
        server, otherwise it will result in undefined behavior.

        This function was introduced in Qt 5.0.

        **See also** **pauseMode** () and **resume** ().
        """
        ...

    def pauseMode(self) -> "QAbstractSocket.PauseMode":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#pauseMode

        **[since 5.0] QAbstractSocket::PauseModes QAbstractSocket::pauseMode()
        const**

        Returns the pause mode of this socket.

        This function was introduced in Qt 5.0.

        **See also** **setPauseMode** () and **resume** ().
        """
        ...

    def resume(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#resume

        **[virtual, since 5.0] void QAbstractSocket::resume()**

        Continues data transfer on the socket. This method should only be used
        after the socket has been set to pause upon notifications and a
        notification has been received. The only notification currently
        supported is **QSslSocket::sslErrors** (). Calling this method if the
        socket is not paused results in undefined behavior.

        This function was introduced in Qt 5.0.

        **See also** **pauseMode** () and **setPauseMode** ().
        """
        ...

    def socketOption(self, option: "QAbstractSocket.SocketOption") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#socketOption

        **[virtual] QVariant
        QAbstractSocket::socketOption(QAbstractSocket::SocketOption option )**

        Returns the value of the **option** option.

        **See also** **setSocketOption** ().
        """
        ...

    def setSocketOption(
        self, option: "QAbstractSocket.SocketOption", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setSocketOption

        **[virtual] void
        QAbstractSocket::setSocketOption(QAbstractSocket::SocketOption option ,
        const QVariant & value )**

        Sets the given **option** to the value described by **value**.

        **Note:** On Windows Runtime, **QAbstractSocket::KeepAliveOption**  must
        be set before the socket is connected.

        **See also** **socketOption** ().
        """
        ...

    def setPeerName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setPeerName

        **[protected] void QAbstractSocket::setPeerName(const QString & name )**

        Sets the host name of the remote peer to **name**.

        You can call this function in a subclass of **QAbstractSocket**  to
        change the return value of the **peerName** () function after a
        connection has been established. This feature is commonly used by proxy
        connections for virtual connection settings.

        **See also** **peerName** ().
        """
        ...

    def setPeerAddress(
        self, address: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setPeerAddress

        **[protected] void QAbstractSocket::setPeerAddress(const QHostAddress &
        address )**

        Sets the address of the remote side of the connection to **address**.

        You can call this function in a subclass of **QAbstractSocket**  to
        change the return value of the **peerAddress** () function after a
        connection has been established. This feature is commonly used by proxy
        connections for virtual connection settings.

        **See also** **peerAddress** (), **setPeerPort** (), and
        **setLocalAddress** ().
        """
        ...

    def setPeerPort(self, port: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setPeerPort

        **[protected] void QAbstractSocket::setPeerPort(quint16 port )**

        Sets the port of the remote side of the connection to **port**.

        You can call this function in a subclass of **QAbstractSocket**  to
        change the return value of the **peerPort** () function after a
        connection has been established. This feature is commonly used by proxy
        connections for virtual connection settings.

        **See also** **peerPort** (), **setPeerAddress** (), and
        **setLocalPort** ().
        """
        ...

    def setLocalAddress(
        self, address: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setLocalAddress

        **[protected] void QAbstractSocket::setLocalAddress(const QHostAddress &
        address )**

        Sets the address on the local side of a connection to **address**.

        You can call this function in a subclass of **QAbstractSocket**  to
        change the return value of the **localAddress** () function after a
        connection has been established. This feature is commonly used by proxy
        connections for virtual connection settings.

        Note that this function does not bind the local address of the socket
        prior to a connection (e.g., **QAbstractSocket::bind** ()).

        **See also** **localAddress** (), **setLocalPort** (), and
        **setPeerAddress** ().
        """
        ...

    def setLocalPort(self, port: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setLocalPort

        **[protected] void QAbstractSocket::setLocalPort(quint16 port )**

        Sets the port on the local side of a connection to **port**.

        You can call this function in a subclass of **QAbstractSocket**  to
        change the return value of the **localPort** () function after a
        connection has been established. This feature is commonly used by proxy
        connections for virtual connection settings.

        Note that this function does not bind the local port of the socket prior
        to a connection (e.g., **QAbstractSocket::bind** ()).

        **See also** **localPort** (), **localAddress** (), **setLocalAddress**
        (), and **setPeerPort** ().
        """
        ...

    def setSocketError(self, socketError: "QAbstractSocket.SocketError") -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setSocketError

        **[protected] void
        QAbstractSocket::setSocketError(QAbstractSocket::SocketError socketError
        )**

        Sets the type of error that last occurred to **socketError**.

        **See also** **setSocketState** () and **setErrorString** ().
        """
        ...

    def setSocketState(self, state: "QAbstractSocket.SocketState") -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setSocketState

        **[protected] void
        QAbstractSocket::setSocketState(QAbstractSocket::SocketState state )**

        Sets the state of the socket to **state**.

        **See also** **state** ().
        """
        ...

    def skipData(self, maxSize: int) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#skipData

        **[override virtual protected] qint64 QAbstractSocket::skipData(qint64
        maxSize )**

        Reimplements: **QIODevice::skipData** (qint64 maxSize).
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#writeData

        **[override virtual protected] qint64 QAbstractSocket::writeData(const
        char * data , qint64 size )**

        Reimplements: **QIODevice::writeData** (const char *data, qint64
        maxSize).
        """
        ...

    def readLineData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#readLineData

        **[override virtual protected] qint64 QAbstractSocket::readLineData(char
        * data , qint64 maxlen )**

        Reimplements: **QIODevice::readLineData** (char *data, qint64 maxSize).
        """
        ...

    def readData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#readData

        **[override virtual protected] qint64 QAbstractSocket::readData(char *
        data , qint64 maxSize )**

        Reimplements: **QIODevice::readData** (char *data, qint64 maxSize).
        """
        ...

    def proxy(self) -> "QNetworkProxy":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#proxy

        **QNetworkProxy QAbstractSocket::proxy() const**

        Returns the network proxy for this socket. By default
        **QNetworkProxy::DefaultProxy**  is used, which means this socket will
        query the default proxy settings for the application.

        **See also** **setProxy** (), **QNetworkProxy** , and
        **QNetworkProxyFactory** .
        """
        ...

    def setProxy(self, networkProxy: "QNetworkProxy") -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setProxy

        **void QAbstractSocket::setProxy(const QNetworkProxy & networkProxy )**

        Sets the explicit network proxy for this socket to **networkProxy**.

        To disable the use of a proxy for this socket, use the
        **QNetworkProxy::NoProxy**  proxy type:

        socket->setProxy(**QNetworkProxy** ::NoProxy);

        The default value for the proxy is **QNetworkProxy::DefaultProxy** ,
        which means the socket will use the application settings: if a proxy is
        set with **QNetworkProxy::setApplicationProxy** , it will use that;
        otherwise, if a factory is set with
        **QNetworkProxyFactory::setApplicationProxyFactory** , it will query
        that factory with type **QNetworkProxyQuery::TcpSocket** .

        **See also** **proxy** (), **QNetworkProxy** , and
        **QNetworkProxyFactory::queryProxy** ().
        """
        ...

    def waitForDisconnected(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#waitForDisconnected

        **[virtual] bool QAbstractSocket::waitForDisconnected(int msecs =
        30000)**

        Waits until the socket has disconnected, up to **msecs** milliseconds.
        If the connection was successfully disconnected, this function returns
        `true`; otherwise it returns `false` (if the operation timed out, if an
        error occurred, or if this **QAbstractSocket**  is already
        disconnected). In the case where it returns `false`, you can call
        **error** () to determine the cause of the error.

        The following example waits up to one second for a connection to be
        closed:

        socket->disconnectFromHost();
            if (socket->state() ==
        **QAbstractSocket** ::UnconnectedState
                ||
        socket->waitForDisconnected(1000)) {
                    **qDebug**
        ("Disconnected!");
            }

        If msecs is -1, this function will not time out.

        **Note:** This function may fail randomly on Windows. Consider using the
        event loop and the **disconnected** () signal if your software will run
        on Windows.

        **See also** **disconnectFromHost** () and **close** ().
        """
        ...

    def waitForBytesWritten(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#waitForBytesWritten

        **[override virtual] bool QAbstractSocket::waitForBytesWritten(int msecs
        = 30000)**

        Reimplements: **QIODevice::waitForBytesWritten** (int msecs).

        This function blocks until at least one byte has been written on the
        socket and the **bytesWritten** () signal has been emitted. The function
        will timeout after **msecs** milliseconds; the default timeout is 30000
        milliseconds.

        The function returns `true` if the **bytesWritten** () signal is
        emitted; otherwise it returns `false` (if an error occurred or the
        operation timed out).

        **Note:** This function may fail randomly on Windows. Consider using the
        event loop and the **bytesWritten** () signal if your software will run
        on Windows.

        **See also** **waitForReadyRead** ().
        """
        ...

    def waitForReadyRead(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#waitForReadyRead

        **[override virtual] bool QAbstractSocket::waitForReadyRead(int msecs =
        30000)**

        Reimplements: **QIODevice::waitForReadyRead** (int msecs).

        This function blocks until new data is available for reading and the
        **readyRead** () signal has been emitted. The function will timeout
        after **msecs** milliseconds; the default timeout is 30000 milliseconds.

        The function returns `true` if the **readyRead** () signal is emitted
        and there is new data available for reading; otherwise it returns
        `false` (if an error occurred or the operation timed out).

        **Note:** This function may fail randomly on Windows. Consider using the
        event loop and the **readyRead** () signal if your software will run on
        Windows.

        **See also** **waitForBytesWritten** ().
        """
        ...

    def waitForConnected(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#waitForConnected

        **[virtual] bool QAbstractSocket::waitForConnected(int msecs = 30000)**

        Waits until the socket is connected, up to **msecs** milliseconds. If
        the connection has been established, this function returns `true`;
        otherwise it returns `false`. In the case where it returns `false`, you
        can call **error** () to determine the cause of the error.

        The following example waits up to one second for a connection to be
        established:

        socket->connectToHost("imap", 143);
            if
        (socket->waitForConnected(1000))
                **qDebug** ("Connected!");

        If msecs is -1, this function will not time out.

        **Note:** This function may wait slightly longer than **msecs** ,
        depending on the time it takes to complete the host lookup.

        **Note:** Multiple calls to this functions do not accumulate the time.
        If the function times out, the connecting process will be aborted.

        **Note:** This function may fail randomly on Windows. Consider using the
        event loop and the **connected** () signal if your software will run on
        Windows.

        **See also** **connectToHost** () and **connected** ().
        """
        ...

    def flush(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#flush

        **bool QAbstractSocket::flush()**

        This function writes as much as possible from the internal write buffer
        to the underlying network socket, without blocking. If any data was
        written, this function returns `true`; otherwise false is returned.

        Call this function if you need **QAbstractSocket**  to start sending
        buffered data immediately. The number of bytes successfully written
        depends on the operating system. In most cases, you do not need to call
        this function, because **QAbstractSocket**  will start sending data
        automatically once control goes back to the event loop. In the absence
        of an event loop, call **waitForBytesWritten** () instead.

        **See also** **write** () and **waitForBytesWritten** ().
        """
        ...

    def isSequential(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#isSequential

        **[override virtual] bool QAbstractSocket::isSequential() const**

        Reimplements: **QIODevice::isSequential() const** .
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#close

        **[override virtual] void QAbstractSocket::close()**

        Reimplements: **QIODevice::close** ().

        Closes the I/O device for the socket and calls **disconnectFromHost** ()
        to close the socket's connection.

        See **QIODevice::close** () for a description of the actions that occur
        when an I/O device is closed.

        **See also** **abort** ().
        """
        ...

    def error(self) -> "QAbstractSocket.SocketError":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#error

        **QAbstractSocket::SocketError QAbstractSocket::error() const**

        Returns the type of error that last occurred.

        **See also** **state** () and **errorString** ().
        """
        ...

    def state(self) -> "QAbstractSocket.SocketState":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#state

        **QAbstractSocket::SocketState QAbstractSocket::state() const**

        Returns the state of the socket.

        **See also** **error** ().
        """
        ...

    def socketType(self) -> "QAbstractSocket.SocketType":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#socketType

        **QAbstractSocket::SocketType QAbstractSocket::socketType() const**

        Returns the socket type (TCP, UDP, or other).

        **See also** **QTcpSocket**  and **QUdpSocket** .
        """
        ...

    def socketDescriptor(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#socketDescriptor

        **[virtual] qintptr QAbstractSocket::socketDescriptor() const**

        Returns the native socket descriptor of the **QAbstractSocket**  object
        if this is available; otherwise returns -1.

        If the socket is using **QNetworkProxy** , the returned descriptor may
        not be usable with native socket functions.

        The socket descriptor is not available when **QAbstractSocket**  is in
        **UnconnectedState** .

        **See also** **setSocketDescriptor** ().
        """
        ...

    def setSocketDescriptor(
        self,
        socketDescriptor: PyQt6.sip.voidptr,
        state: "QAbstractSocket.SocketState" = ...,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setSocketDescriptor

        **[virtual] bool QAbstractSocket::setSocketDescriptor(qintptr
        socketDescriptor , QAbstractSocket::SocketState socketState =
        ConnectedState, QIODeviceBase::OpenMode openMode = ReadWrite)**

        Initializes **QAbstractSocket**  with the native socket descriptor
        **socketDescriptor**. Returns `true` if **socketDescriptor** is accepted
        as a valid socket descriptor; otherwise returns `false`. The socket is
        opened in the mode specified by **openMode** , and enters the socket
        state specified by **socketState**. Read and write buffers are cleared,
        discarding any pending data.

        **Note:** It is not possible to initialize two abstract sockets with the
        same native socket descriptor.

        **See also** **socketDescriptor** ().
        """
        ...

    def abort(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#abort

        **void QAbstractSocket::abort()**

        Aborts the current connection and resets the socket. Unlike
        **disconnectFromHost** (), this function immediately closes the socket,
        discarding any pending data in the write buffer.

        **See also** **disconnectFromHost** () and **close** ().
        """
        ...

    def setReadBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#setReadBufferSize

        **[virtual] void QAbstractSocket::setReadBufferSize(qint64 size )**

        Sets the size of **QAbstractSocket** 's internal read buffer to be
        **size** bytes.

        If the buffer size is limited to a certain size, **QAbstractSocket**
        won't buffer more than this size of data. Exceptionally, a buffer size
        of 0 means that the read buffer is unlimited and all incoming data is
        buffered. This is the default.

        This option is useful if you only read the data at certain points in
        time (e.g., in a real-time streaming application) or if you want to
        protect your socket against receiving too much data, which may
        eventually cause your application to run out of memory.

        Only **QTcpSocket**  uses **QAbstractSocket** 's internal buffer;
        **QUdpSocket**  does not use any buffering at all, but rather relies on
        the implicit buffering provided by the operating system. Because of
        this, calling this function on **QUdpSocket**  has no effect.

        **See also** **readBufferSize** () and **read** ().
        """
        ...

    def readBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#readBufferSize

        **qint64 QAbstractSocket::readBufferSize() const**

        Returns the size of the internal read buffer. This limits the amount of
        data that the client can receive before you call **read** () or
        **readAll** ().

        A read buffer size of 0 (the default) means that the buffer has no size
        limit, ensuring that no data is lost.

        **See also** **setReadBufferSize** () and **read** ().
        """
        ...

    def peerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#peerName

        **QString QAbstractSocket::peerName() const**

        Returns the name of the peer as specified by **connectToHost** (), or an
        empty **QString**  if **connectToHost** () has not been called.

        **See also** **peerAddress** (), **peerPort** (), and **setPeerName**
        ().
        """
        ...

    def peerAddress(self) -> "QHostAddress":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#peerAddress

        **QHostAddress QAbstractSocket::peerAddress() const**

        Returns the address of the connected peer if the socket is in
        **ConnectedState** ; otherwise returns **QHostAddress::Null** .

        **See also** **peerName** (), **peerPort** (), **localAddress** (), and
        **setPeerAddress** ().
        """
        ...

    def peerPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#peerPort

        **quint16 QAbstractSocket::peerPort() const**

        Returns the port of the connected peer if the socket is in
        **ConnectedState** ; otherwise returns 0.

        **See also** **peerAddress** (), **localPort** (), and **setPeerPort**
        ().
        """
        ...

    def localAddress(self) -> "QHostAddress":
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#localAddress

        **QHostAddress QAbstractSocket::localAddress() const**

        Returns the host address of the local socket if available; otherwise
        returns **QHostAddress::Null** .

        This is normally the main IP address of the host, but can be
        **QHostAddress::LocalHost**  (127.0.0.1) for connections to the local
        host.

        **See also** **localPort** (), **peerAddress** (), and
        **setLocalAddress** ().
        """
        ...

    def localPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#localPort

        **quint16 QAbstractSocket::localPort() const**

        Returns the host port number (in native byte order) of the local socket
        if available; otherwise returns 0.

        **See also** **localAddress** (), **peerPort** (), and **setLocalPort**
        ().
        """
        ...

    def bytesToWrite(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#bytesToWrite

        **[override virtual] qint64 QAbstractSocket::bytesToWrite() const**

        Reimplements: **QIODevice::bytesToWrite() const** .

        Returns the number of bytes that are waiting to be written. The bytes
        are written when control goes back to the event loop or when **flush**
        () is called.

        **See also** **bytesAvailable** () and **flush** ().
        """
        ...

    def bytesAvailable(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#bytesAvailable

        **[override virtual] qint64 QAbstractSocket::bytesAvailable() const**

        Reimplements: **QIODevice::bytesAvailable() const** .

        Returns the number of incoming bytes that are waiting to be read.

        **See also** **bytesToWrite** () and **read** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#isValid

        **bool QAbstractSocket::isValid() const**

        Returns `true` if the socket is valid and ready for use; otherwise
        returns `false`.

        **Note:** The socket's state must be **ConnectedState**  before reading
        and writing can occur.

        **See also** **state** ().
        """
        ...

    def disconnectFromHost(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#disconnectFromHost

        **[virtual] void QAbstractSocket::disconnectFromHost()**

        Attempts to close the socket. If there is pending data waiting to be
        written, **QAbstractSocket**  will enter **ClosingState**  and wait
        until all data has been written. Eventually, it will enter
        **UnconnectedState**  and emit the **disconnected** () signal.

        **See also** **connectToHost** ().
        """
        ...

    @typing.overload
    def connectToHost(
        self,
        hostName: str,
        port: int,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
        protocol: "QAbstractSocket.NetworkLayerProtocol" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#connectToHost

        **[virtual] void QAbstractSocket::connectToHost(const QString & hostName
        , quint16 port , QIODeviceBase::OpenMode openMode = ReadWrite,
        QAbstractSocket::NetworkLayerProtocol protocol = AnyIPProtocol)**

        Attempts to make a connection to **hostName** on the given **port**. The
        **protocol** parameter can be used to specify which network protocol to
        use (eg. IPv4 or IPv6).

        The socket is opened in the given **openMode** and first enters
        **HostLookupState** , then performs a host name lookup of **hostName**.
        If the lookup succeeds, **hostFound** () is emitted and
        **QAbstractSocket**  enters **ConnectingState** . It then attempts to
        connect to the address or addresses returned by the lookup. Finally, if
        a connection is established, **QAbstractSocket**  enters
        **ConnectedState**  and emits **connected** ().

        At any point, the socket can emit **errorOccurred** () to signal that an
        error occurred.

        **hostName** may be an IP address in string form (e.g., "43.195.83.32"),
        or it may be a host name (e.g., "example.com"). **QAbstractSocket**
        will do a lookup only if required. **port** is in native byte order.

        **See also** **state** (), **peerName** (), **peerAddress** (),
        **peerPort** (), and **waitForConnected** ().
        """
        ...

    @typing.overload
    def connectToHost(
        self,
        address: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"],
        port: int,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#connectToHost-1

        **void QAbstractSocket::connectToHost(const QHostAddress & address ,
        quint16 port , QIODeviceBase::OpenMode openMode = ReadWrite)**

        This is an overloaded function.

        Attempts to make a connection to **address** on port **port**.
        """
        ...

    @property
    def connected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#connected

        **[signal] void QAbstractSocket::connected()**

        This signal is emitted after **connectToHost** () has been called and a
        connection has been successfully established.

        **Note:** On some operating systems the connected() signal may be
        directly emitted from the **connectToHost** () call for connections to
        the localhost.

        **See also** **connectToHost** () and **disconnected** ().
        """
        ...

    @property
    def disconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#disconnected

        **[signal] void QAbstractSocket::disconnected()**

        This signal is emitted when the socket has been disconnected.

        **Warning:** If you need to delete the **sender** () of this signal in a
        slot connected to it, use the **deleteLater** () function.

        **See also** **connectToHost** (), **disconnectFromHost** (), and
        **abort** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#errorOccurred

        **[signal, since 5.15] void
        QAbstractSocket::errorOccurred(QAbstractSocket::SocketError socketError
        )**

        This signal is emitted after an error occurred. The **socketError**
        parameter describes the type of error that occurred.

        When this signal is emitted, the socket may not be ready for a reconnect
        attempt. In that case, attempts to reconnect should be done from the
        event loop. For example, use a **QTimer::singleShot** () with 0 as the
        timeout.

        **QAbstractSocket::SocketError**  is not a registered metatype, so for
        queued connections, you will have to register it with
        **Q_DECLARE_METATYPE** () and **qRegisterMetaType** ().

        This function was introduced in Qt 5.15.

        **See also** **error** (), **errorString** (), and **Creating Custom Qt
        Types** .
        """
        ...

    @property
    def hostFound(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#hostFound

        **[signal] void QAbstractSocket::hostFound()**

        This signal is emitted after **connectToHost** () has been called and
        the host lookup has succeeded.

        **Note:** Since Qt 4.6.3 **QAbstractSocket**  may emit hostFound()
        directly from the **connectToHost** () call since a DNS result could
        have been cached.

        **See also** **connected** ().
        """
        ...

    @property
    def proxyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#proxyAuthenticationRequired

        **[signal] void QAbstractSocket::proxyAuthenticationRequired(const
        QNetworkProxy & proxy , QAuthenticator * authenticator )**

        This signal can be emitted when a **proxy** that requires authentication
        is used. The **authenticator** object can then be filled in with the
        required details to allow authentication and continue the connection.

        **Note:** It is not possible to use a QueuedConnection to connect to
        this signal, as the connection will fail if the authenticator has not
        been filled in with new information when the signal returns.

        **See also** **QAuthenticator**  and **QNetworkProxy** .
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractsocket.html#stateChanged

        **[signal] void
        QAbstractSocket::stateChanged(QAbstractSocket::SocketState socketState
        )**

        This signal is emitted whenever **QAbstractSocket** 's state changes.
        The **socketState** parameter is the new state.

        **QAbstractSocket::SocketState**  is not a registered metatype, so for
        queued connections, you will have to register it with
        **Q_DECLARE_METATYPE** () and **qRegisterMetaType** ().

        **See also** **state** () and **Creating Custom Qt Types** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QClipboard(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qclipboard.html

    **Detailed Description**

    The clipboard offers a simple mechanism to copy and paste data between
    applications.

    QClipboard supports the same data types that **QDrag**  does, and uses
    similar mechanisms. For advanced clipboard usage read **Drag and Drop** .

    There is a single QClipboard object in an application, accessible as
    **QGuiApplication::clipboard** ().

    Example:

    QClipboard *clipboard = **QGuiApplication** ::clipboard();
        **QString**
    originalText = clipboard->text();
        // etc.
    clipboard->setText(newText);

    QClipboard features some convenience functions to access common data types:
    **setText** () allows the exchange of Unicode text and **setPixmap** () and
    **setImage** () allows the exchange of QPixmaps and QImages between
    applications. The **setMimeData** () function is the ultimate in
    flexibility: it allows you to add any **QMimeData**  into the clipboard.
    There are corresponding getters for each of these, e.g. **text** (),
    **image** () and **pixmap** (). You can clear the clipboard by calling
    **clear** ().

    A typical example of the use of these functions follows:

    void DropArea::paste()
        {
            const QClipboard *clipboard =
    **QApplication** ::clipboard();
            const **QMimeData**  *mimeData =
    clipboard->mimeData();

            if (mimeData->hasImage()) {
    setPixmap(qvariant_cast<**QPixmap** >(mimeData->imageData()));
            }
    else if (mimeData->hasHtml()) {
                setText(mimeData->html());
    setTextFormat(Qt::RichText);
            } else if (mimeData->hasText()) {
    setText(mimeData->text());
                setTextFormat(Qt::PlainText);
    } else {
                setText(tr("Cannot display data"));
            }
        }

    **Notes for X11 Users**

    * The X11 Window System has the concept of a separate selection and
    clipboard. When text is selected, it is immediately available as the global
    mouse selection. The global mouse selection may later be copied to the
    clipboard. By convention, the middle mouse button is used to paste the
    global mouse selection.
      * X11 also has the concept of ownership; if you
    change the selection within a window, X11 will only notify the owner and the
    previous owner of the change, i.e. it will not notify all applications that
    the selection or clipboard data changed.
      * Lastly, the X11 clipboard is
    event driven, i.e. the clipboard will not function properly if the event
    loop is not running. Similarly, it is recommended that the contents of the
    clipboard are stored or retrieved in direct response to user-input events,
    e.g. mouse button or key presses and releases. You should not store or
    retrieve the clipboard contents in response to timer or non-user-input
    events.
      * Since there is no standard way to copy and paste files between
    applications on X11, various MIME types and conventions are currently in
    use. For instance, Nautilus expects files to be supplied with a
    `x-special/gnome-copied-files` MIME type with data beginning with the
    cut/copy action, a newline character, and the URL of the file.

    **Notes for macOS Users**

    macOS supports a separate find buffer that holds the current search string
    in Find operations. This find clipboard can be accessed by specifying the
    **FindBuffer**  mode.

    **Notes for Windows and macOS Users**

    * Windows and macOS do not support the global mouse selection; they only
    supports the global clipboard, i.e. they only add text to the clipboard when
    an explicit copy or cut is made.
      * Windows and macOS does not have the
    concept of ownership; the clipboard is a fully global resource so all
    applications are notified of changes.

    **See also** **QGuiApplication** .
    """

    class Mode(enum.Enum):
        Clipboard: QClipboard = ...
        Selection: QClipboard = ...
        FindBuffer: QClipboard = ...

    def setPixmap(self, a0: QPixmap, mode: "QClipboard.Mode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qclipboard.html#setPixmap

        **void QClipboard::setPixmap(const QPixmap & pixmap , QClipboard::Mode
        mode = Clipboard)**

        Copies **pixmap** into the clipboard. Note that this is slower than
        **setImage** () because it needs to convert the **QPixmap**  to a
        **QImage**  first.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the pixmap
        is stored in the global clipboard. If **mode** is
        **QClipboard::Selection** , the pixmap is stored in the global mouse
        selection.

        **See also** **pixmap** (), **setImage** (), and **setMimeData** ().
        """
        ...

    def setImage(self, a0: "QImage", mode: "QClipboard.Mode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qclipboard.html#setImage

        **void QClipboard::setImage(const QImage & image , QClipboard::Mode mode
        = Clipboard)**

        Copies the **image** into the clipboard.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the image
        is stored in the global clipboard. If **mode** is
        **QClipboard::Selection** , the data is stored in the global mouse
        selection.

        This is shorthand for:

        **QMimeData**  *data = new **QMimeData** ;
        data->setImageData(image);
            clipboard->setMimeData(data, mode);

        **See also** **image** (), **setPixmap** (), and **setMimeData** ().
        """
        ...

    def pixmap(self, mode: "QClipboard.Mode" = ...) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qclipboard.html#pixmap

        **QPixmap QClipboard::pixmap(QClipboard::Mode mode = Clipboard) const**

        Returns the clipboard pixmap, or null if the clipboard does not contain
        a pixmap. Note that this can lose information. For example, if the image
        is 24-bit and the display is 8-bit, the result is converted to 8 bits,
        and if the image has an alpha channel, the result just has a mask.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the pixmap
        is retrieved from the global clipboard. If **mode** is
        **QClipboard::Selection** , the pixmap is retrieved from the global
        mouse selection.

        **See also** **setPixmap** (), **image** (), **mimeData** (), and
        **QPixmap::convertFromImage** ().
        """
        ...

    def image(self, mode: "QClipboard.Mode" = ...) -> "QImage":
        """
        https://doc.qt.io/qt-6/qclipboard.html#image

        **QImage QClipboard::image(QClipboard::Mode mode = Clipboard) const**

        Returns the clipboard image, or returns a null image if the clipboard
        does not contain an image or if it contains an image in an unsupported
        image format.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the image
        is retrieved from the global clipboard. If **mode** is
        **QClipboard::Selection** , the image is retrieved from the global mouse
        selection.

        **See also** **setImage** (), **pixmap** (), **mimeData** (), and
        **QImage::isNull** ().
        """
        ...

    def setMimeData(
        self, data: QtCore.QMimeData, mode: "QClipboard.Mode" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qclipboard.html#setMimeData

        **void QClipboard::setMimeData(QMimeData * src , QClipboard::Mode mode =
        Clipboard)**

        Sets the clipboard data to **src**. Ownership of the data is transferred
        to the clipboard. If you want to remove the data either call **clear**
        () or call setMimeData() again with new data.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the data
        is stored in the global clipboard. If **mode** is
        **QClipboard::Selection** , the data is stored in the global mouse
        selection. If **mode** is **QClipboard::FindBuffer** , the data is
        stored in the search string buffer.

        The **setText** (), **setImage** () and **setPixmap** () functions are
        simpler wrappers for setting text, image and pixmap data respectively.

        **See also** **mimeData** ().
        """
        ...

    def mimeData(self, mode: "QClipboard.Mode" = ...) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qclipboard.html#mimeData

        **const QMimeData *QClipboard::mimeData(QClipboard::Mode mode =
        Clipboard) const**

        Returns a pointer to a **QMimeData**  representation of the current
        clipboard data (can be `nullptr` if the given **mode** is not supported
        by the platform).

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the data
        is retrieved from the global clipboard. If **mode** is
        **QClipboard::Selection** , the data is retrieved from the global mouse
        selection. If **mode** is **QClipboard::FindBuffer** , the data is
        retrieved from the search string buffer.

        The **text** (), **image** (), and **pixmap** () functions are simpler
        wrappers for retrieving text, image, and pixmap data.

        **Note:** The pointer returned might become invalidated when the
        contents of the clipboard changes; either by calling one of the setter
        functions or externally by the system clipboard changing.

        **See also** **setMimeData** ().
        """
        ...

    def setText(self, a0: str, mode: "QClipboard.Mode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qclipboard.html#setText

        **void QClipboard::setText(const QString & text , QClipboard::Mode mode
        = Clipboard)**

        Copies **text** into the clipboard as plain text.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the text
        is stored in the global clipboard. If **mode** is
        **QClipboard::Selection** , the text is stored in the global mouse
        selection. If **mode** is **QClipboard::FindBuffer** , the text is
        stored in the search string buffer.

        **See also** **text** () and **setMimeData** ().
        """
        ...

    @typing.overload
    def text(self, mode: "QClipboard.Mode" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qclipboard.html#text

        **QString QClipboard::text(QClipboard::Mode mode = Clipboard) const**

        Returns the clipboard text as plain text, or an empty string if the
        clipboard does not contain any text.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the text
        is retrieved from the global clipboard. If **mode** is
        **QClipboard::Selection** , the text is retrieved from the global mouse
        selection. If **mode** is **QClipboard::FindBuffer** , the text is
        retrieved from the search string buffer.

        **See also** **setText** () and **mimeData** ().
        """
        ...

    @typing.overload
    def text(
        self, subtype: str, mode: "QClipboard.Mode" = ...
    ) -> typing.Tuple[str, str]:
        """
        https://doc.qt.io/qt-6/qclipboard.html#text-1

        **QString QClipboard::text(QString & subtype , QClipboard::Mode mode =
        Clipboard) const**

        This is an overloaded function.

        Returns the clipboard text in subtype **subtype** , or an empty string
        if the clipboard does not contain any text. If **subtype** is null, any
        subtype is acceptable, and **subtype** is set to the chosen subtype.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , the text
        is retrieved from the global clipboard. If **mode** is
        **QClipboard::Selection** , the text is retrieved from the global mouse
        selection.

        Common values for **subtype** are "plain" and "html".

        Note that calling this function repeatedly, for instance from a key
        event handler, may be slow. In such cases, you should use the
        `dataChanged()` signal instead.

        **See also** **setText** () and **mimeData** ().
        """
        ...

    def ownsSelection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qclipboard.html#ownsSelection

        **bool QClipboard::ownsSelection() const**

        Returns `true` if this clipboard object owns the mouse selection data;
        otherwise returns `false`.
        """
        ...

    def ownsFindBuffer(self) -> bool:
        """
        https://doc.qt.io/qt-6/qclipboard.html#ownsFindBuffer

        **bool QClipboard::ownsFindBuffer() const**

        Returns `true` if this clipboard object owns the find buffer data;
        otherwise returns `false`.
        """
        ...

    def ownsClipboard(self) -> bool:
        """
        https://doc.qt.io/qt-6/qclipboard.html#ownsClipboard

        **bool QClipboard::ownsClipboard() const**

        Returns `true` if this clipboard object owns the clipboard data;
        otherwise returns `false`.
        """
        ...

    def supportsSelection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qclipboard.html#supportsSelection

        **bool QClipboard::supportsSelection() const**

        Returns `true` if the clipboard supports mouse selection; otherwise
        returns `false`.
        """
        ...

    def supportsFindBuffer(self) -> bool:
        """
        https://doc.qt.io/qt-6/qclipboard.html#supportsFindBuffer

        **bool QClipboard::supportsFindBuffer() const**

        Returns `true` if the clipboard supports a separate search buffer;
        otherwise returns `false`.
        """
        ...

    def clear(self, mode: "QClipboard.Mode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qclipboard.html#clear

        **void QClipboard::clear(QClipboard::Mode mode = Clipboard)**

        Clear the clipboard contents.

        The **mode** argument is used to control which part of the system
        clipboard is used. If **mode** is **QClipboard::Clipboard** , this
        function clears the global clipboard contents. If **mode** is
        **QClipboard::Selection** , this function clears the global mouse
        selection contents. If **mode** is **QClipboard::FindBuffer** , this
        function clears the search string buffer.

        **See also** **QClipboard::Mode**  and **supportsSelection** ().
        """
        ...

    @property
    def changed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qclipboard.html#changed

        **[signal] void QClipboard::changed(QClipboard::Mode mode )**

        This signal is emitted when the data for the given clipboard **mode** is
        changed.

        **See also** **dataChanged** (), **selectionChanged** (), and
        **findBufferChanged** ().
        """
        ...

    @property
    def dataChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qclipboard.html#dataChanged

        **[signal] void QClipboard::dataChanged()**

        This signal is emitted when the clipboard data is changed.

        On macOS and with Qt version 4.3 or higher, clipboard changes made by
        other applications will only be detected when the application is
        activated.

        **See also** **findBufferChanged** (), **selectionChanged** (), and
        **changed** ().
        """
        ...

    @property
    def findBufferChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qclipboard.html#findBufferChanged

        **[signal] void QClipboard::findBufferChanged()**

        This signal is emitted when the find buffer is changed. This only
        applies to macOS.

        With Qt version 4.3 or higher, clipboard changes made by other
        applications will only be detected when the application is activated.

        **See also** **dataChanged** (), **selectionChanged** (), and
        **changed** ().
        """
        ...

    @property
    def selectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qclipboard.html#selectionChanged

        **[signal] void QClipboard::selectionChanged()**

        This signal is emitted when the selection is changed. This only applies
        to windowing systems that support selections, e.g. X11. Windows and
        macOS don't support selections.

        **See also** **dataChanged** (), **findBufferChanged** (), and
        **changed** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsScale(QGraphicsTransform):
    """
    https://doc.qt.io/qt-6/qgraphicsscale.html

    **Detailed Description**

    **QGraphicsScene**  provides certain parameters to help control how the
    scale should be applied.

    The origin is the point that the item is scaled from (i.e., it stays fixed
    relative to the parent as the rest of the item grows). By default the origin
    is **QPointF** (0, 0).

    The parameters **xScale** , **yScale** , and **zScale**  describe the scale
    factors to apply in horizontal, vertical, and depth directions. They can
    take on any value, including 0 (to collapse the item to a point) or negative
    value. A negative **xScale**  value will mirror the item horizontally. A
    negative **yScale**  value will flip the item vertically. A negative
    **zScale**  will flip the item end for end.

    **See also** **QGraphicsTransform** , **QGraphicsItem::setScale** (), and
    **QTransform::scale** ().
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#QGraphicsScale

        **QGraphicsScale::QGraphicsScale(QObject * parent = nullptr)**

        Constructs an empty QGraphicsScale object with the given **parent**.
        """
        ...

    def applyTo(self, matrix: QtGui.QMatrix4x4) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#applyTo

        **[override virtual] void QGraphicsScale::applyTo(QMatrix4x4 * matrix )
        const**

        Reimplements: **QGraphicsTransform::applyTo(QMatrix4x4 *matrix) const**
        .
        """
        ...

    def setZScale(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#zScale-prop

        **zScale : qreal**

        This property holds the depth scale factor.

        The scale factor can be any real number; the default value is 1.0. If
        you set the factor to 0.0, the item will be collapsed to a single point.
        If you provide a negative value, the item will be flipped end for end
        around its origin.

        **Access functions:**

        qreal **zScale** () const
        void **setZScale** (qreal)

        **Notifier signal:**

        void ****zScaleChanged** ** ()

        **See also** **xScale** , **yScale** , and **origin** .

        **Member Function Documentation**
        """
        ...

    def zScale(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#zScale-prop

        **zScale : qreal**

        This property holds the depth scale factor.

        The scale factor can be any real number; the default value is 1.0. If
        you set the factor to 0.0, the item will be collapsed to a single point.
        If you provide a negative value, the item will be flipped end for end
        around its origin.

        **Access functions:**

        qreal **zScale** () const
        void **setZScale** (qreal)

        **Notifier signal:**

        void ****zScaleChanged** ** ()

        **See also** **xScale** , **yScale** , and **origin** .

        **Member Function Documentation**
        """
        ...

    def setYScale(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#yScale-prop

        **yScale : qreal**

        This property holds the vertical scale factor.

        The scale factor can be any real number; the default value is 1.0. If
        you set the factor to 0.0, the item will be collapsed to a single point.
        If you provide a negative value, the item will be flipped vertically
        around its origin.

        **Access functions:**

        qreal **yScale** () const
        void **setYScale** (qreal)

        **Notifier signal:**

        void ****yScaleChanged** ** ()

        **See also** **xScale** , **zScale** , and **origin** .
        """
        ...

    def yScale(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#yScale-prop

        **yScale : qreal**

        This property holds the vertical scale factor.

        The scale factor can be any real number; the default value is 1.0. If
        you set the factor to 0.0, the item will be collapsed to a single point.
        If you provide a negative value, the item will be flipped vertically
        around its origin.

        **Access functions:**

        qreal **yScale** () const
        void **setYScale** (qreal)

        **Notifier signal:**

        void ****yScaleChanged** ** ()

        **See also** **xScale** , **zScale** , and **origin** .
        """
        ...

    def setXScale(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#xScale-prop

        **xScale : qreal**

        This property holds the horizontal scale factor.

        The scale factor can be any real number; the default value is 1.0. If
        you set the factor to 0.0, the item will be collapsed to a single point.
        If you provide a negative value, the item will be mirrored horizontally
        around its origin.

        **Access functions:**

        qreal **xScale** () const
        void **setXScale** (qreal)

        **Notifier signal:**

        void ****xScaleChanged** ** ()

        **See also** **yScale** , **zScale** , and **origin** .
        """
        ...

    def xScale(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#xScale-prop

        **xScale : qreal**

        This property holds the horizontal scale factor.

        The scale factor can be any real number; the default value is 1.0. If
        you set the factor to 0.0, the item will be collapsed to a single point.
        If you provide a negative value, the item will be mirrored horizontally
        around its origin.

        **Access functions:**

        qreal **xScale** () const
        void **setXScale** (qreal)

        **Notifier signal:**

        void ****xScaleChanged** ** ()

        **See also** **yScale** , **zScale** , and **origin** .
        """
        ...

    def setOrigin(self, point: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#origin-prop

        **origin : QVector3D**

        This property holds the origin of the scale in 3D space.

        All scaling will be done relative to this point (i.e., this point will
        stay fixed, relative to the parent, when the item is scaled).

        **Access functions:**

        QVector3D **origin** () const
        void **setOrigin** (const QVector3D &
        **point** )

        **Notifier signal:**

        void ****originChanged** ** ()

        **See also** **xScale** , **yScale** , and **zScale** .
        """
        ...

    def origin(self) -> QtGui.QVector3D:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#origin-prop

        **origin : QVector3D**

        This property holds the origin of the scale in 3D space.

        All scaling will be done relative to this point (i.e., this point will
        stay fixed, relative to the parent, when the item is scaled).

        **Access functions:**

        QVector3D **origin** () const
        void **setOrigin** (const QVector3D &
        **point** )

        **Notifier signal:**

        void ****originChanged** ** ()

        **See also** **xScale** , **yScale** , and **zScale** .
        """
        ...

    @property
    def originChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#originChanged

        **[signal] void QGraphicsScale::originChanged()**

        **QGraphicsScale**  emits this signal when its origin changes.

        **Note:** Notifier signal for property **origin** .

        **See also** **QGraphicsScale::origin** .
        """
        ...

    @property
    def scaleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#scaleChanged

        **[signal] void QGraphicsScale::scaleChanged()**

        This signal is emitted whenever the **xScale** , **yScale** , or
        **zScale**  of the object changes.

        **See also** **QGraphicsScale::xScale** , **QGraphicsScale::yScale** ,
        and **QGraphicsScale::zScale** .
        """
        ...

    @property
    def xScaleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#xScaleChanged

        **[signal] void QGraphicsScale::xScaleChanged()**

        This signal is emitted whenever the **xScale**  property changes.

        **Note:** Notifier signal for property **xScale** .
        """
        ...

    @property
    def yScaleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#yScaleChanged

        **[signal] void QGraphicsScale::yScaleChanged()**

        This signal is emitted whenever the **yScale**  property changes.

        **Note:** Notifier signal for property **yScale** .
        """
        ...

    @property
    def zScaleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsscale.html#zScaleChanged

        **[signal] void QGraphicsScale::zScaleChanged()**

        This signal is emitted whenever the **zScale**  property changes.

        **Note:** Notifier signal for property **zScale** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QBitArray(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbitarray.html

    **Detailed Description**

    A QBitArray is an array that gives access to individual bits and provides
    operators (**AND** , **OR** , **XOR** , and **NOT** ) that work on entire
    arrays of bits. It uses **implicit sharing**  (copy-on-write) to reduce
    memory usage and to avoid the needless copying of data.

    The following code constructs a QBitArray containing 200 bits initialized to
    false (0):

    **QBitArray**  ba(200);

    To initialize the bits to true, either pass `true` as second argument to the
    constructor, or call **fill** () later on.

    QBitArray uses 0-based indexes, just like C++ arrays. To access the bit at a
    particular index position, you can use operator[](). On non-const bit
    arrays, operator[]() returns a reference to a bit that can be used on the
    left side of an assignment. For example:

    **QBitArray**  ba;
        ba.resize(3);
        ba[0] = true;
        ba[1] = false;
    ba[2] = true;

    For technical reasons, it is more efficient to use **testBit** () and
    **setBit** () to access bits in the array than operator[](). For example:

    **QBitArray**  ba(3);
        ba.setBit(0, true);
        ba.setBit(1, false);
    ba.setBit(2, true);

    QBitArray supports `&` (**AND** ), `|` (**OR** ), `^` (**XOR** ), `~`
    (**NOT** ), as well as `&=`, `|=`, and `^=`. These operators work in the
    same way as the built-in C++ bitwise operators of the same name. For
    example:

    **QBitArray**  x(5);
        x.setBit(3, true);
        // x: [ 0, 0, 0, 1, 0 ]
    **QBitArray**  y(5);
        y.setBit(4, true);
        // y: [ 0, 0, 0, 0, 1 ]
    x |= y;
        // x: [ 0, 0, 0, 1, 1 ]

    For historical reasons, QBitArray distinguishes between a null bit array and
    an empty bit array. A **null** bit array is a bit array that is initialized
    using QBitArray's default constructor. An **empty** bit array is any bit
    array with size 0. A null bit array is always empty, but an empty bit array
    isn't necessarily null:

    **QBitArray** ().isNull();           // returns true
        **QBitArray**
    ().isEmpty();          // returns true

        **QBitArray** (0).isNull();
    // returns false
        **QBitArray** (0).isEmpty();         // returns true
    **QBitArray** (3).isNull();          // returns false
        **QBitArray**
    (3).isEmpty();         // returns false

    All functions except **isNull** () treat null bit arrays the same as empty
    bit arrays; for example, QBitArray() compares equal to QBitArray(0). We
    recommend that you always use **isEmpty** () and avoid **isNull** ().

    **See also** **QByteArray**  and **QList** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#QBitArray

        **QBitArray::QBitArray()**

        Constructs an empty bit array.

        **See also** **isEmpty** ().
        """
        ...

    @typing.overload
    def __init__(self, size: int, value: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#QBitArray-1

        **QBitArray::QBitArray(qsizetype size , bool value = false)**

        Constructs a bit array containing **size** bits. The bits are
        initialized with **value** , which defaults to false (0).
        """
        ...

    @typing.overload
    def __init__(self, other: "QBitArray") -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#QBitArray-2

        **QBitArray::QBitArray(const QBitArray & other )**

        Constructs a copy of **other**.

        This operation takes **constant time** , because QBitArray is
        **implicitly shared** . This makes returning a QBitArray from a function
        very fast. If a shared instance is modified, it will be copied (copy-on-
        write), and that takes **linear time** .

        **See also** **operator=** ().
        """
        ...

    def toUInt32(self, endianness: "QSysInfo.Endian") -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qbitarray.html#toUInt32

        **[since 6.0] quint32 QBitArray::toUInt32(QSysInfo::Endian endianness ,
        bool * ok = nullptr) const**

        Returns the array of bit converted to an int. The conversion is based on
        **endianness**. Converts up to the first 32 bits of the array to
        `quint32` and returns it, obeying **endianness**. If **ok** is not a
        null pointer, and the array has more than 32 bits, **ok** is set to
        false and this function returns zero; otherwise, it's set to true.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def fromBits(data: bytes, len: int) -> "QBitArray":
        """
        https://doc.qt.io/qt-6/qbitarray.html#fromBits

        **[static, since 5.11] QBitArray QBitArray::fromBits(const char * data ,
        qsizetype size )**

        Creates a **QBitArray**  with the dense bit array located at **data** ,
        with **size** bits. The byte array at **data** must be at least **size**
        / 8 (rounded up) bytes long.

        If **size** is not a multiple of 8, this function will include the
        lowest **size** % 8 bits from the last byte in **data**.

        This function was introduced in Qt 5.11.

        **See also** **bits** ().
        """
        ...

    def bits(self) -> bytes:
        """
        https://doc.qt.io/qt-6/qbitarray.html#bits

        **[since 5.11] const char *QBitArray::bits() const**

        Returns a pointer to a dense bit array for this **QBitArray** . Bits are
        counted upwards from the least significant bit in each byte. The number
        of bits relevant in the last byte is given by `size() % 8`.

        This function was introduced in Qt 5.11.

        **See also** **fromBits** () and **size** ().
        """
        ...

    def swap(self, other: "QBitArray") -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#swap

        **void QBitArray::swap(QBitArray & other )**

        Swaps bit array **other** with this bit array. This operation is very
        fast and never fails.
        """
        ...

    def __hash__(self) -> int:
        ...

    def at(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qbitarray.html#at

        **bool QBitArray::at(qsizetype i ) const**

        Returns the value of the bit at index position **i**.

        **i** must be a valid index position in the bit array (i.e., 0 <= **i**
        < **size** ()).

        **See also** **operator[]** ().
        """
        ...

    def __getitem__(self, i: int) -> bool:
        ...

    def toggleBit(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qbitarray.html#toggleBit

        **bool QBitArray::toggleBit(qsizetype i )**

        Inverts the value of the bit at index position **i** , returning the
        previous value of that bit as either true (if it was set) or false (if
        it was unset).

        If the previous value was 0, the new value will be 1. If the previous
        value was 1, the new value will be 0.

        **i** must be a valid index position in the bit array (i.e., 0 <= **i**
        < **size** ()).

        **See also** **setBit** () and **clearBit** ().
        """
        ...

    def clearBit(self, i: int) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#clearBit

        **void QBitArray::clearBit(qsizetype i )**

        Sets the bit at index position **i** to 0.

        **i** must be a valid index position in the bit array (i.e., 0 <= **i**
        < **size** ()).

        **See also** **setBit** () and **toggleBit** ().
        """
        ...

    @typing.overload
    def setBit(self, i: int) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#setBit

        **void QBitArray::setBit(qsizetype i )**

        Sets the bit at index position **i** to 1.

        **i** must be a valid index position in the bit array (i.e., 0 <= **i**
        < **size** ()).

        **See also** **clearBit** () and **toggleBit** ().
        """
        ...

    @typing.overload
    def setBit(self, i: int, val: bool) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#setBit-1

        **void QBitArray::setBit(qsizetype i , bool value )**

        This is an overloaded function.

        Sets the bit at index position **i** to **value**.
        """
        ...

    def testBit(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qbitarray.html#testBit

        **bool QBitArray::testBit(qsizetype i ) const**

        Returns `true` if the bit at index position **i** is 1; otherwise
        returns `false`.

        **i** must be a valid index position in the bit array (i.e., 0 <= **i**
        < **size** ()).

        **See also** **setBit** () and **clearBit** ().
        """
        ...

    def truncate(self, pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#truncate

        **void QBitArray::truncate(qsizetype pos )**

        Truncates the bit array at index position **pos**.

        If **pos** is beyond the end of the array, nothing happens.

        **See also** **resize** ().
        """
        ...

    @typing.overload
    def fill(self, val: bool, first: int, last: int) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#fill

        **bool QBitArray::fill(bool value , qsizetype size = -1)**

        Sets every bit in the bit array to **value** , returning true if
        successful; otherwise returns `false`. If **size** is different from -1
        (the default), the bit array is resized to **size** beforehand.

        Example:

        **QBitArray**  ba(8);
            ba.fill(true);
            // ba: [ 1, 1, 1, 1, 1, 1,
        1, 1 ]

            ba.fill(false, 2);
            // ba: [ 0, 0 ]

        **See also** **resize** ().
        """
        ...

    @typing.overload
    def fill(self, val: bool, size: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qbitarray.html#fill-1

        **void QBitArray::fill(bool value , qsizetype begin , qsizetype end )**

        This is an overloaded function.

        Sets bits at index positions **begin** up to (but not including) **end**
        to **value**.

        **begin** must be a valid index position in the bit array (0 <=
        **begin** < **size** ()).

        **end** must be either a valid index position or equal to **size** (),
        in which case the fill operation runs until the end of the array (0 <=
        **end** <= **size** ()).

        Example:

        **QBitArray**  ba(4);
            ba.fill(true, 1, 2);            // ba: [ 0, 1,
        0, 0 ]
            ba.fill(true, 1, 3);            // ba: [ 0, 1, 1, 0 ]
        ba.fill(true, 1, 4);            // ba: [ 0, 1, 1, 1 ]
        """
        ...

    def __invert__(self) -> "QBitArray":
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#clear

        **void QBitArray::clear()**

        Clears the contents of the bit array and makes it empty.

        **See also** **resize** () and **isEmpty** ().
        """
        ...

    def isDetached(self) -> bool:
        ...

    def detach(self) -> None:
        ...

    def resize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qbitarray.html#resize

        **void QBitArray::resize(qsizetype size )**

        Resizes the bit array to **size** bits.

        If **size** is greater than the current size, the bit array is extended
        to make it **size** bits with the extra bits added to the end. The new
        bits are initialized to false (0).

        If **size** is less than the current size, bits are removed from the
        end.

        **See also** **size** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbitarray.html#isNull

        **bool QBitArray::isNull() const**

        Returns `true` if this bit array is null; otherwise returns `false`.

        Example:

        **QBitArray** ().isNull();           // returns true
            **QBitArray**
        (0).isNull();          // returns false
            **QBitArray** (3).isNull();
        // returns false

        Qt makes a distinction between null bit arrays and empty bit arrays for
        historical reasons. For most applications, what matters is whether or
        not a bit array contains any data, and this can be determined using
        **isEmpty** ().

        **See also** **isEmpty** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbitarray.html#isEmpty

        **bool QBitArray::isEmpty() const**

        Returns `true` if this bit array has size 0; otherwise returns false.

        **See also** **size** ().
        """
        ...

    def __len__(self) -> int:
        ...

    @typing.overload
    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qbitarray.html#count

        **qsizetype QBitArray::count() const**

        Same as **size** ().
        """
        ...

    @typing.overload
    def count(self, on: bool) -> int:
        """
        https://doc.qt.io/qt-6/qbitarray.html#count-1

        **qsizetype QBitArray::count(bool on ) const**

        If **on** is true, this function returns the number of 1-bits stored in
        the bit array; otherwise the number of 0-bits is returned.
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qbitarray.html#size

        **qsizetype QBitArray::size() const**

        Returns the number of bits stored in the bit array.

        **See also** **resize** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QVideoSink(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qvideosink.html

    **Detailed Description**

    The QVideoSink class can be used to retrieve video data on a frame by frame
    basis from Qt Multimedia.

    QVideoSink can operate in two modes. In the first mode, it can render the
    video stream to a native window of the underlying windowing system. In the
    other mode, it will provide individual video frames to the application
    developer through the videoFrameChanged() signal.

    The video frame can then be used to read out the data of those frames and
    handle them further. When using **QPainter** , the **QVideoFrame**  can be
    drawing using the paint() method in QVideoSink.

    **QVideoFrame**  objects can consume a significant amount of memory or
    system resources and should thus not be held for longer than required by the
    application.

    **See also** **QMediaPlayer**  and **QMediaCaptureSession** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qvideosink.html#QVideoSink

        **QVideoSink::QVideoSink(QObject * parent = nullptr)**

        Constructs a new QVideoSink object with **parent**.
        """
        ...

    def videoFrame(self) -> QVideoFrame:
        """
        https://doc.qt.io/qt-6/qvideosink.html#videoFrame

        **QVideoFrame QVideoSink::videoFrame() const**

        Returns the current video frame.

        **See also** **setVideoFrame** ().
        """
        ...

    def setVideoFrame(self, frame: QVideoFrame) -> None:
        """
        https://doc.qt.io/qt-6/qvideosink.html#setVideoFrame

        **void QVideoSink::setVideoFrame(const QVideoFrame & frame )**

        Sets the current video **frame**.

        **See also** **videoFrame** ().
        """
        ...

    def setSubtitleText(self, subtitle: str) -> None:
        """
        https://doc.qt.io/qt-6/qvideosink.html#setSubtitleText

        **void QVideoSink::setSubtitleText(const QString & subtitle )**

        Sets the current **subtitle** text.

        **See also** **subtitleText** ().
        """
        ...

    def subtitleText(self) -> str:
        """
        https://doc.qt.io/qt-6/qvideosink.html#subtitleText

        **QString QVideoSink::subtitleText() const**

        Returns the current subtitle text.

        **See also** **setSubtitleText** ().
        """
        ...

    def videoSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qvideosink.html#videoSize

        **QSize QVideoSink::videoSize() const**

        Returns the size of the video currently being played back. If no video
        is being played, this method returns an invalid size.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui


class QOpenGLVersionProfile(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglversionprofile.html

    **Detailed Description**

    An object of this class can be passed to QOpenGLContext::versionFunctions()
    to request a functions object for a specific version and profile of OpenGL.

    It also contains some helper functions to check if a version supports
    profiles or is a legacy version.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#QOpenGLVersionProfile

        **QOpenGLVersionProfile::QOpenGLVersionProfile()**

        Creates a default invalid QOpenGLVersionProfile object.
        """
        ...

    @typing.overload
    def __init__(self, format: QtGui.QSurfaceFormat) -> None:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#QOpenGLVersionProfile-
        1

        **QOpenGLVersionProfile::QOpenGLVersionProfile(const QSurfaceFormat &
        format )**

        Creates a QOpenGLVersionProfile object initialised with the version and
        profile from **format**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QOpenGLVersionProfile") -> None:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#QOpenGLVersionProfile-
        2

        **QOpenGLVersionProfile::QOpenGLVersionProfile(const
        QOpenGLVersionProfile & other )**

        Constructs a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#isValid

        **bool QOpenGLVersionProfile::isValid() const**

        Returns `true` if the version number is valid. Note that for a default
        constructed **QOpenGLVersionProfile**  object this function will return
        `false`.

        **See also** **setVersion** () and **version** ().
        """
        ...

    def isLegacyVersion(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#isLegacyVersion

        **bool QOpenGLVersionProfile::isLegacyVersion() const**

        Returns `true` is the OpenGL version returned by **version** () contains
        deprecated functions and does not support profiles i.e. if the OpenGL
        version is <= 3.1.
        """
        ...

    def hasProfiles(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#hasProfiles

        **bool QOpenGLVersionProfile::hasProfiles() const**

        Returns `true` if profiles are supported by the OpenGL version returned
        by **version** (). Only OpenGL versions >= 3.2 support profiles.

        **See also** **profile** () and **version** ().
        """
        ...

    def setProfile(self, profile: QtGui.QSurfaceFormat.OpenGLContextProfile) -> None:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#setProfile

        **void
        QOpenGLVersionProfile::setProfile(QSurfaceFormat::OpenGLContextProfile
        profile )**

        Sets the OpenGL profile **profile**. Only makes sense if profiles are
        supported by this version.

        **See also** **profile** ().
        """
        ...

    def profile(self) -> QtGui.QSurfaceFormat.OpenGLContextProfile:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#profile

        **QSurfaceFormat::OpenGLContextProfile QOpenGLVersionProfile::profile()
        const**

        Returns the OpenGL profile. Only makes sense if profiles are supported
        by this version.

        **See also** **setProfile** ().
        """
        ...

    def setVersion(self, majorVersion: int, minorVersion: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#setVersion

        **void QOpenGLVersionProfile::setVersion(int majorVersion , int
        minorVersion )**

        Sets the major and minor version numbers to **majorVersion** and
        **minorVersion** respectively.

        **See also** **version** ().
        """
        ...

    def version(self) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qopenglversionprofile.html#version

        **QPair<int, int> QOpenGLVersionProfile::version() const**

        Returns a QPair<int,int> where the components represent the major and
        minor OpenGL version numbers respectively.

        **See also** **setVersion** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QBrush(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbrush.html

    **Detailed Description**

    A brush has a style, a color, a gradient and a texture.

    The brush **style** () defines the fill pattern using the **Qt::BrushStyle**
    enum. The default brush style is **Qt::NoBrush**  (depending on how you
    construct a brush). This style tells the painter to not fill shapes. The
    standard style for filling is **Qt::SolidPattern** . The style can be set
    when the brush is created using the appropriate constructor, and in addition
    the **setStyle** () function provides means for altering the style once the
    brush is constructed.

    ![Brush Styles](images/brush-styles.png)

    The brush **color** () defines the color of the fill pattern. The color can
    either be one of Qt's predefined colors, **Qt::GlobalColor** , or any other
    custom **QColor** . The currently set color can be retrieved and altered
    using the **color** () and **setColor** () functions, respectively.

    The **gradient** () defines the gradient fill used when the current style is
    either **Qt::LinearGradientPattern** , **Qt::RadialGradientPattern**  or
    **Qt::ConicalGradientPattern** . Gradient brushes are created by giving a
    **QGradient**  as a constructor argument when creating the QBrush. Qt
    provides three different gradients: **QLinearGradient** ,
    **QConicalGradient** , and **QRadialGradient**  \\- all of which inherit
    **QGradient** .

    **QRadialGradient**  gradient(50, 50, 50, 50, 50);
    gradient.setColorAt(0, **QColor** ::fromRgbF(0, 1, 0, 1));
    gradient.setColorAt(1, **QColor** ::fromRgbF(0, 0, 0, 0));
    **QBrush**  brush(gradient);

    The **texture** () defines the pixmap used when the current style is
    **Qt::TexturePattern** . You can create a brush with a texture by providing
    the pixmap when the brush is created or by using **setTexture** ().

    Note that applying **setTexture** () makes **style** () ==
    **Qt::TexturePattern** , regardless of previous style settings. Also,
    calling **setColor** () will not make a difference if the style is a
    gradient. The same is the case if the style is **Qt::TexturePattern**  style
    unless the current texture is a **QBitmap** .

    The **isOpaque** () function returns `true` if the brush is fully opaque
    otherwise false. A brush is considered opaque if:

    * The alpha component of the **color** () is 255.
      * Its **texture** ()
    does not have an alpha channel and is not a **QBitmap** .
      * The colors in
    the **gradient** () all have an alpha component that is 255.

    ![Outlines](images/brush-outline.png)To specify the style and color of lines
    and outlines, use the **QPainter** 's **pen**  combined with
    **Qt::PenStyle**  and **Qt::GlobalColor** :



        **QPainter**
    painter(this);

        painter.setBrush(Qt::cyan);
    painter.setPen(Qt::darkCyan);
        painter.drawRect(0, 0, 100,100);
    painter.setBrush(Qt::NoBrush);
        painter.setPen(Qt::darkGreen);
    painter.drawRect(40, 40, 100, 100);

    Note that, by default, **QPainter**
    renders the outline (using the currently set pen) when drawing shapes. Use
    [`painter.setPen(Qt::NoPen)`**  to disable this behavior.

    For more information about painting in general, see the **Paint System** .

    **See also** **Qt::BrushStyle** , **QPainter** , and **QColor** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush

        **QBrush::QBrush()**

        Constructs a default black brush with the style **Qt::NoBrush**  (i.e.
        this brush will not fill shapes).
        """
        ...

    @typing.overload
    def __init__(self, bs: QtCore.Qt.BrushStyle) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-1

        **QBrush::QBrush(Qt::BrushStyle style )**

        Constructs a black brush with the given **style**.

        **See also** **setStyle** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        color: typing.Union[QColor, QtCore.Qt.GlobalColor, int],
        style: QtCore.Qt.BrushStyle = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-2

        **QBrush::QBrush(const QColor & color , Qt::BrushStyle style =
        Qt::SolidPattern)**

        Constructs a brush with the given **color** and **style**.

        **See also** **setColor** () and **setStyle** ().
        """
        ...

    @typing.overload
    def __init__(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int], pixmap: QPixmap
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-3

        **QBrush::QBrush(Qt::GlobalColor color , Qt::BrushStyle style =
        Qt::SolidPattern)**

        Constructs a brush with the given **color** and **style**.

        **See also** **setColor** () and **setStyle** ().
        """
        ...

    @typing.overload
    def __init__(self, pixmap: QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-4

        **QBrush::QBrush(const QColor & color , const QPixmap & pixmap )**

        Constructs a brush with the given **color** and the custom pattern
        stored in **pixmap**.

        The style is set to **Qt::TexturePattern** . The color will only have an
        effect for QBitmaps.

        **See also** **setColor** () and **setTexture** ().
        """
        ...

    @typing.overload
    def __init__(self, image: "QImage") -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-5

        **QBrush::QBrush(Qt::GlobalColor color , const QPixmap & pixmap )**

        Constructs a brush with the given **color** and the custom pattern
        stored in **pixmap**.

        The style is set to **Qt::TexturePattern** . The color will only have an
        effect for QBitmaps.

        **See also** **setColor** () and **setTexture** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        brush: typing.Union["QBrush", QColor, QtCore.Qt.GlobalColor, int, "QGradient"],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-6

        **QBrush::QBrush(const QPixmap & pixmap )**

        Constructs a brush with a black color and a texture set to the given
        **pixmap**. The style is set to **Qt::TexturePattern** .

        **See also** **setTexture** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#QBrush-7

        **QBrush::QBrush(const QImage & image )**

        Constructs a brush with a black color and a texture set to the given
        **image**. The style is set to **Qt::TexturePattern** .

        **See also** **setTextureImage** ().
        """
        ...

    def swap(self, other: "QBrush") -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#swap

        **void QBrush::swap(QBrush & other )**

        Swaps brush **other** with this brush. This operation is very fast and
        never fails.
        """
        ...

    def transform(self) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qbrush.html#transform

        **QTransform QBrush::transform() const**

        Returns the current transformation matrix for the brush.

        **See also** **setTransform** ().
        """
        ...

    def setTransform(self, a0: "QTransform") -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#setTransform

        **void QBrush::setTransform(const QTransform & matrix )**

        Sets **matrix** as an explicit transformation matrix on the current
        brush. The brush transformation matrix is merged with **QPainter**
        transformation matrix to produce the final result.

        **See also** **transform** ().
        """
        ...

    def textureImage(self) -> "QImage":
        """
        https://doc.qt.io/qt-6/qbrush.html#textureImage

        **QImage QBrush::textureImage() const**

        Returns the custom brush pattern, or a null image if no custom brush
        pattern has been set.

        If the texture was set as a **QPixmap**  it will be converted to a
        **QImage** .

        **See also** **setTextureImage** ().
        """
        ...

    def setTextureImage(self, image: "QImage") -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#setTextureImage

        **void QBrush::setTextureImage(const QImage & image )**

        Sets the brush image to **image**. The style is set to
        **Qt::TexturePattern** .

        Note the current brush color will **not** have any affect on monochrome
        images, as opposed to calling **setTexture** () with a **QBitmap** . If
        you want to change the color of monochrome image brushes, either convert
        the image to **QBitmap**  with `QBitmap::fromImage()` and set the
        resulting **QBitmap**  as a texture, or change the entries in the color
        table for the image.

        **See also** **textureImage** () and **setTexture** ().
        """
        ...

    def color(self) -> QColor:
        """
        https://doc.qt.io/qt-6/qbrush.html#color

        **const QColor &QBrush::color() const**

        Returns the brush color.

        **See also** **setColor** ().
        """
        ...

    def style(self) -> QtCore.Qt.BrushStyle:
        """
        https://doc.qt.io/qt-6/qbrush.html#style

        **Qt::BrushStyle QBrush::style() const**

        Returns the brush style.

        **See also** **setStyle** ().
        """
        ...

    def isOpaque(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbrush.html#isOpaque

        **bool QBrush::isOpaque() const**

        Returns `true` if the brush is fully opaque otherwise false. A brush is
        considered opaque if:

        * The alpha component of the **color** () is 255.
          * Its **texture** ()
        does not have an alpha channel and is not a **QBitmap** .
          * The colors
        in the **gradient** () all have an alpha component that is 255.
          * It
        is an extended radial gradient.
        """
        ...

    def gradient(self) -> "QGradient":
        """
        https://doc.qt.io/qt-6/qbrush.html#gradient

        **const QGradient *QBrush::gradient() const**

        Returns the gradient describing this brush.
        """
        ...

    @typing.overload
    def setColor(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, "QGradient"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#setColor

        **void QBrush::setColor(const QColor & color )**

        Sets the brush color to the given **color**.

        Note that calling setColor() will not make a difference if the style is
        a gradient. The same is the case if the style is **Qt::TexturePattern**
        style unless the current texture is a **QBitmap** .

        **See also** **color** ().
        """
        ...

    @typing.overload
    def setColor(self, acolor: QtCore.Qt.GlobalColor) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#setColor-1

        **void QBrush::setColor(Qt::GlobalColor color )**

        This is an overloaded function.

        Sets the brush color to the given **color**.
        """
        ...

    def setTexture(self, pixmap: QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#setTexture

        **void QBrush::setTexture(const QPixmap & pixmap )**

        Sets the brush pixmap to **pixmap**. The style is set to
        **Qt::TexturePattern** .

        The current brush color will only have an effect for monochrome pixmaps,
        i.e. for **QPixmap::depth** () == 1 (**QBitmaps** ).

        **See also** **texture** ().
        """
        ...

    def texture(self) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qbrush.html#texture

        **QPixmap QBrush::texture() const**

        Returns the custom brush pattern, or a null pixmap if no custom brush
        pattern has been set.

        **See also** **setTexture** ().
        """
        ...

    def setStyle(self, a0: QtCore.Qt.BrushStyle) -> None:
        """
        https://doc.qt.io/qt-6/qbrush.html#setStyle

        **void QBrush::setStyle(Qt::BrushStyle style )**

        Sets the brush style to **style**.

        **See also** **style** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6.QAxContainer import *


class QAxWidget(QAxBaseWidget, QAxBase):
    """
    https://doc.qt.io/qt-6/qaxwidget.html

    **Detailed Description**

    A QAxWidget can be instantiated as an empty object, with the name of the
    ActiveX control it should wrap, or with an existing interface pointer to the
    ActiveX control. The ActiveX control's properties, methods and events which
    only use **QAxBase**  supported data types, become available as Qt
    properties, slots and signals. The base class **QAxBase**  provides an API
    to access the ActiveX directly through the `IUnknown` pointer.

    QAxWidget is a **QWidget**  and can mostly be used as such, e.g. it can be
    organized in a widget hierarchy and layouts or act as an event filter.
    Standard widget properties, e.g. **enabled**  are supported, but it depends
    on the ActiveX control to implement support for ambient properties like e.g.
    palette or font. QAxWidget tries to provide the necessary hints.

    However, you cannot reimplement Qt-specific event handlers like
    mousePressEvent or keyPressEvent and expect them to be called reliably. The
    embedded control covers the QAxWidget completely, and usually handles the
    user interface itself. Use control-specific APIs (i.e. listen to the signals
    of the control), or use standard COM techniques like window procedure
    subclassing.

    QAxWidget also inherits most of its ActiveX-related functionality from
    **QAxBase** , notably **dynamicCall** () and **querySubObject** ().

    **Warning:** You can subclass QAxWidget, but you cannot use the `Q_OBJECT`
    macro in the subclass (the generated moc-file will not compile), so you
    cannot add further signals, slots or properties. This limitation is due to
    the metaobject information generated in runtime. To work around this
    problem, aggregate the QAxWidget as a member of the **QObject**  subclass.

    **See also** **QAxBase** , **QAxObject** , **QAxScript** , and **ActiveQt
    Framework** .
    """

    @typing.overload
    def __init__(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#QAxWidget

        **QAxWidget::QAxWidget(QWidget * parent = nullptr, Qt::WindowFlags f =
        Qt::WindowFlags())**

        Creates an empty QAxWidget widget and propagates **parent** and **f** to
        the **QWidget**  constructor. To initialize a control, call
        **setControl** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: str,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#QAxWidget-1

        **QAxWidget::QAxWidget(const QString & c , QWidget * parent = nullptr,
        Qt::WindowFlags f = Qt::WindowFlags())**

        Creates an QAxWidget widget and initializes the ActiveX control **c**.
        **parent** and **f** are propagated to the **QWidget**  contructor.

        **See also** **setControl** ().
        """
        ...

    def connectNotify(self, a0: QtCore.QMetaMethod) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#connectNotify

        **[override virtual protected] void QAxWidget::connectNotify(const
        QMetaMethod & signal )**

        Reimplements: **QObject::connectNotify** (const QMetaMethod &signal).
        """
        ...

    def translateKeyEvent(self, a0: int, a1: int) -> bool:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#translateKeyEvent

        **[virtual protected] bool QAxWidget::translateKeyEvent(int message ,
        int keycode ) const**

        Reimplement this function to pass certain key events to the ActiveX
        control. **message** is the Window message identifier specifying the
        message type (ie. WM_KEYDOWN), and **keycode** is the virtual keycode
        (ie. VK_TAB).

        If the function returns true the key event is passed on to the ActiveX
        control, which then either processes the event or passes the event on to
        Qt.

        If the function returns false the processing of the key event is ignored
        by ActiveQt, ie. the ActiveX control might handle it or not.

        The default implementation returns true for the following cases:

        WM_SYSKEYDOWNWM_SYSKEYUPWM_KEYDOWN
        All keycodesVK_MENUVK_TAB,
        VK_DELETE and all non-arrow-keys in combination with VK_SHIFT,
        VK_CONTROL or VK_MENU

        This table is the result of experimenting with popular ActiveX controls,
        ie. Internet Explorer and Microsoft Office applications, but for some
        controls it might require modification.
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#resizeEvent

        **[override virtual protected] void QAxWidget::resizeEvent(QResizeEvent
        *)**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#changeEvent

        **[override virtual protected] void QAxWidget::changeEvent(QEvent * e
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    @typing.overload
    def createHostWindow(self, a0: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#createHostWindow

        **[virtual protected] bool QAxWidget::createHostWindow(bool initialized
        )**

        Creates the client site for the ActiveX control, and returns true if the
        control could be embedded successfully, otherwise returns false. If
        **initialized** is true the control has already been initialized.

        This function is called by **initialize** (). If you reimplement
        initialize to customize the actual control instantiation, call this
        function in your reimplementation to have the control embedded by the
        default client side. Creates the client site for the ActiveX control,
        and returns true if the control could be embedded successfully,
        otherwise returns false.
        """
        ...

    @typing.overload
    def createHostWindow(self, a0: bool, a1: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#createHostWindow-1

        **[protected] bool QAxWidget::createHostWindow(bool initialized , const
        QByteArray & data )**

        Creates the client site for the ActiveX control, and returns true if the
        control could be embedded successfully, otherwise returns false. If
        **initialized** is false the control will be initialized using the
        **data**. The control will be initialized through either
        IPersistStreamInit or IPersistStorage interface.

        If the control needs to be initialized using custom data, call this
        function in your reimplementation of **initialize** (). This function is
        not called by the default implementation of **initialize** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#minimumSizeHint

        **[override virtual] QSize QAxWidget::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#sizeHint

        **[override virtual] QSize QAxWidget::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def doVerb(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#doVerb

        **bool QAxWidget::doVerb(const QString & verb )**

        Requests the ActiveX control to perform the action **verb**. The
        possible verbs are returned by **verbs** ().

        The function returns true if the object could perform the action,
        otherwise returns false.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#clear

        **void QAxWidget::clear()**

        Shuts down the ActiveX control.

        **See also** **resetControl** ().
        """
        ...

    def resetControl(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxwidget.html#resetControl

        **[override virtual] void QAxWidget::resetControl()**

        Reimplements: **QAxObjectInterface::resetControl** ().

        Shuts down the ActiveX control.
        """
        ...

    def setControl(self, c: str) -> bool:
        ...

    def control(self) -> str:
        ...

    def setClassContext(self, classContext: int) -> None:
        ...

    def classContext(self) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QWaitCondition(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qwaitcondition.html

    **Detailed Description**

    QWaitCondition allows a thread to tell other threads that some sort of
    condition has been met. One or many threads can block waiting for a
    QWaitCondition to set a condition with **wakeOne** () or **wakeAll** (). Use
    **wakeOne** () to wake one randomly selected thread or **wakeAll** () to
    wake them all.

    For example, let's suppose that we have three tasks that should be performed
    whenever the user presses a key. Each task could be split into a thread,
    each of which would have a **run** () body like this:

    forever {
            mutex.lock();
            keyPressed.wait(&mutex);
    do_something();
            mutex.unlock();
        }

    Here, the `keyPressed` variable is a global variable of type QWaitCondition.

    A fourth thread would read key presses and wake the other three threads up
    every time it receives one, like this:

    forever {
            getchar();
            keyPressed.wakeAll();
        }

    The order in which the three threads are woken up is undefined. Also, if
    some of the threads are still in `do_something()` when the key is pressed,
    they won't be woken up (since they're not waiting on the condition variable)
    and so the task will not be performed for that key press. This issue can be
    solved using a counter and a **QMutex**  to guard it. For example, here's
    the new code for the worker threads:

    forever {
            mutex.lock();
            keyPressed.wait(&mutex);
    ++count;
            mutex.unlock();

            do_something();
    mutex.lock();
            --count;
            mutex.unlock();
        }

    Here's the code for the fourth thread:

    forever {
            getchar();

            mutex.lock();
            // Sleep
    until there are no busy worker threads
            while (count > 0) {
    mutex.unlock();
                sleep(1);
                mutex.lock();
            }
    keyPressed.wakeAll();
            mutex.unlock();
        }

    The mutex is necessary because the results of two threads attempting to
    change the value of the same variable simultaneously are unpredictable.

    Wait conditions are a powerful thread synchronization primitive. The **Wait
    Conditions Example**  example shows how to use QWaitCondition as an
    alternative to **QSemaphore**  for controlling access to a circular buffer
    shared by a producer thread and a consumer thread.

    **See also** **QMutex** , **QSemaphore** , **QThread** , and **Wait
    Conditions Example** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#QWaitCondition

        **QWaitCondition::QWaitCondition()**

        Constructs a new wait condition object.
        """
        ...

    def wakeAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#wakeAll

        **void QWaitCondition::wakeAll()**

        Wakes all threads waiting on the wait condition. The order in which the
        threads are woken up depends on the operating system's scheduling
        policies and cannot be controlled or predicted.

        **See also** **wakeOne** ().
        """
        ...

    def wakeOne(self) -> None:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#wakeOne

        **void QWaitCondition::wakeOne()**

        Wakes one thread waiting on the wait condition. The thread that is woken
        up depends on the operating system's scheduling policies, and cannot be
        controlled or predicted.

        If you want to wake up a specific thread, the solution is typically to
        use different wait conditions and have different threads wait on
        different conditions.

        **See also** **wakeAll** ().
        """
        ...

    @typing.overload
    def wait(self, lockedMutex: QMutex, deadline: QDeadlineTimer = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#wait

        **[since 5.12] bool QWaitCondition::wait(QMutex * lockedMutex ,
        QDeadlineTimer deadline = QDeadlineTimer(QDeadlineTimer::Forever))**

        Releases the **lockedMutex** and waits on the wait condition. The
        **lockedMutex** must be initially locked by the calling thread. If
        **lockedMutex** is not in a locked state, the behavior is undefined. If
        **lockedMutex** is a recursive mutex, this function returns immediately.
        The **lockedMutex** will be unlocked, and the calling thread will block
        until either of these conditions is met:

        * Another thread signals it using **wakeOne** () or **wakeAll** (). This
        function will return true in this case.
          * the deadline given by
        **deadline** is reached. If **deadline** is `QDeadlineTimer::Forever`
        (the default), then the wait will never timeout (the event must be
        signalled). This function will return false if the wait timed out.

        The **lockedMutex** will be returned to the same locked state. This
        function is provided to allow the atomic transition from the locked
        state to the wait state.

        This function was introduced in Qt 5.12.

        **See also** **wakeOne** () and **wakeAll** ().
        """
        ...

    @typing.overload
    def wait(self, lockedMutex: QMutex, time: int) -> bool:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#wait-1

        **bool QWaitCondition::wait(QMutex * lockedMutex , unsigned long time
        )**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def wait(
        self, lockedReadWriteLock: QReadWriteLock, deadline: QDeadlineTimer = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#wait-2

        **[since 5.12] bool QWaitCondition::wait(QReadWriteLock *
        lockedReadWriteLock , QDeadlineTimer deadline =
        QDeadlineTimer(QDeadlineTimer::Forever))**

        Releases the **lockedReadWriteLock** and waits on the wait condition.
        The **lockedReadWriteLock** must be initially locked by the calling
        thread. If **lockedReadWriteLock** is not in a locked state, this
        function returns immediately. The **lockedReadWriteLock** must not be
        locked recursively, otherwise this function will not release the lock
        properly. The **lockedReadWriteLock** will be unlocked, and the calling
        thread will block until either of these conditions is met:

        * Another thread signals it using **wakeOne** () or **wakeAll** (). This
        function will return true in this case.
          * the deadline given by
        **deadline** is reached. If **deadline** is `QDeadlineTimer::Forever`
        (the default), then the wait will never timeout (the event must be
        signalled). This function will return false if the wait timed out.

        The **lockedReadWriteLock** will be returned to the same locked state.
        This function is provided to allow the atomic transition from the locked
        state to the wait state.

        This function was introduced in Qt 5.12.

        **See also** **wakeOne** () and **wakeAll** ().
        """
        ...

    @typing.overload
    def wait(self, lockedReadWriteLock: QReadWriteLock, time: int) -> bool:
        """
        https://doc.qt.io/qt-6/qwaitcondition.html#wait-3

        **bool QWaitCondition::wait(QReadWriteLock * lockedReadWriteLock ,
        unsigned long time )**

        This is an overloaded function.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtGui import *


class QRasterWindow(QPaintDeviceWindow):
    """
    https://doc.qt.io/qt-6/qrasterwindow.html

    **Detailed Description**

    QRasterWindow is a **QWindow**  with a raster-based, non-OpenGL surface. On
    top of the functionality offered by **QWindow** , QRasterWindow adds a
    virtual **paintEvent** () function and the possibility to open a
    **QPainter**  on itself. The underlying paint engine will be the raster one,
    meaning that all drawing will happen on the CPU. For performing accelerated,
    OpenGL-based drawing, use **QOpenGLWindow**  instead.

    Internally the class is thin wrapper for **QWindow**  and **QBackingStore**
    and is very similar to the **Raster Window Example**  that uses these
    classes directly.

    **See also** **QPaintDeviceWindow::paintEvent** () and
    **QPaintDeviceWindow::update** ().
    """

    def __init__(self, parent: typing.Optional[QWindow] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qrasterwindow.html#QRasterWindow

        **QRasterWindow::QRasterWindow(QWindow * parent = nullptr)**

        Constructs a new QRasterWindow with **parent**.
        """
        ...

    def metric(self, metric: QPaintDevice.PaintDeviceMetric) -> int:
        ...
